@@ -1,6 +1,6 @@
 ###############################################################################
 #                                                                             #
-# Copyright (C) 2004-2014 Edward d'Auvergne                                   #
+# Copyright (C) 2004-2015 Edward d'Auvergne                                   #
 # Copyright (C) 2014 Troels E. Linnet                                         #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
@@ -40,7 +40,7 @@ from status import Status; status = Status()
 
 
 class Relax_fit:
-    def __init__(self, pipe_name=None, pipe_bundle=None, file_root='rx', results_dir=None, grid_inc='11', mc_sim_num=500, view_plots=True):
+    def __init__(self, pipe_name=None, pipe_bundle=None, file_root='rx', results_dir=None, grid_inc=11, mc_sim_num=500, view_plots=True):
         """Perform relaxation curve fitting.
 
         To use this auto-analysis, a data pipe with all the required data needs to be set up.  This data pipe should contain the following:
@@ -48,7 +48,7 @@ class Relax_fit:
             - All the spins loaded.
             - Unresolved spins deselected.
             - All the peak intensities loaded and relaxation delay times set.
-            - Either the baseplane noise RMDS values should be set or replicated spectra loaded.
+            - Either the baseplane noise RMSD values should be set or replicated spectra loaded.
 
         @keyword pipe_name:     The name of the data pipe containing all of the data for the analysis.
         @type pipe_name:        str
@@ -113,9 +113,6 @@ class Relax_fit:
         # Peak intensity error analysis.
         self.error_analysis()
 
-        # Set the relaxation curve type.
-        self.interpreter.relax_fit.select_model('exp')
-
         # Grid search.
         self.interpreter.minimise.grid_search(inc=self.grid_inc)
 
@@ -129,7 +126,19 @@ class Relax_fit:
         self.interpreter.minimise.execute('newton', scaling=False, constraints=False)
         self.interpreter.monte_carlo.error_analysis()
 
-        # Save the relaxation rates.
+        # Determine the normalisation type and if the Iinf parameter exists.
+        norm_type = 'last'
+        iinf = True
+        for spin in spin_loop(skip_desel=True):
+            if spin.model not in ['sat', 'inv']:
+                norm_type = 'first'
+                iinf = False
+                break
+
+        # Save the relaxation rates and other parameter values.
+        self.interpreter.value.write(param='i0', file='i0.out', dir=self.results_dir, force=True)
+        if iinf:
+            self.interpreter.value.write(param='iinf', file='iinf.out', dir=self.results_dir, force=True)
         self.interpreter.value.write(param='rx', file=self.file_root+'.out', dir=self.results_dir, force=True)
 
         # Save the results.
@@ -138,9 +147,11 @@ class Relax_fit:
         # Create Grace plots of the data.
         self.interpreter.grace.write(y_data_type='chi2', file='chi2.agr', dir=self.grace_dir, force=True)    # Minimised chi-squared value.
         self.interpreter.grace.write(y_data_type='i0', file='i0.agr', dir=self.grace_dir, force=True)    # Initial peak intensity.
+        if iinf:
+            self.interpreter.grace.write(y_data_type='iinf', file='iinf.agr', dir=self.grace_dir, force=True)    # Infinite peak intensity.
         self.interpreter.grace.write(y_data_type='rx', file=self.file_root+'.agr', dir=self.grace_dir, force=True)    # Relaxation rate.
         self.interpreter.grace.write(x_data_type='relax_times', y_data_type='peak_intensity', file='intensities.agr', dir=self.grace_dir, force=True)    # Average peak intensities.
-        self.interpreter.grace.write(x_data_type='relax_times', y_data_type='peak_intensity', norm=True, file='intensities_norm.agr', dir=self.grace_dir, force=True)    # Average peak intensities (normalised).
+        self.interpreter.grace.write(x_data_type='relax_times', y_data_type='peak_intensity', norm_type=norm_type, norm=True, file='intensities_norm.agr', dir=self.grace_dir, force=True)    # Average peak intensities (normalised).
 
         # Write a python "grace to PNG/EPS/SVG..." conversion script.
         # Open the file for writing.
@@ -205,15 +216,15 @@ class Relax_fit:
         has_dub = False
 
         if not hasattr(cdp, 'replicates'):
-            # Collect all times, and matching spectrum id.
+            # Collect all times, and matching spectrum ID.
             all_times = []
             all_id = []
-            for s_id, time in cdp.relax_times.iteritems():
-                all_times.append(time)
-                all_id.append(s_id)
+            for spectrum_id in cdp.relax_times:
+                all_times.append(cdp.relax_times[spectrum_id])
+                all_id.append(spectrum_id)
 
             # Get the dublicates.
-            dublicates = map(lambda val: (val, [i for i in xrange(len(all_times)) if all_times[i] == val]), all_times)
+            dublicates = [(val, [i for i in range(len(all_times)) if all_times[i] == val]) for val in all_times]
 
             # Loop over the list of the mapping of times and duplications.
             list_dub_mapping = []
