@@ -1,6 +1,6 @@
 ###############################################################################
 #                                                                             #
-# Copyright (C) 2003-2014 Edward d'Auvergne                                   #
+# Copyright (C) 2003-2015 Edward d'Auvergne                                   #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
 #                                                                             #
@@ -32,6 +32,7 @@ import xml.dom.minidom
 # relax module imports.
 from data_store.gui import Gui
 from data_store.pipe_container import PipeContainer
+from data_store.seq_align import Sequence_alignments
 import pipe_control
 from lib.compat import builtins
 from lib.errors import RelaxError, RelaxPipeError, RelaxNoPipeError
@@ -48,7 +49,8 @@ __all__ = [ 'align_tensor',
             'interatomic',
             'mol_res_spin',
             'pipe_container',
-            'prototype'
+            'prototype',
+            'seq_align'
 ]
 
 
@@ -91,7 +93,7 @@ class Relax_data_store(dict):
         # The data pipes.
         text = text + "\n"
         text = text + "Data pipes:\n"
-        pipes = list(self.instance.keys())
+        pipes = sorted(self.instance.keys())
         if pipes:
             for pipe in pipes:
                 text = text + "  %s\n" % repr(pipe)
@@ -121,7 +123,7 @@ class Relax_data_store(dict):
                 continue
 
             # Skip overwritten methods.
-            if name in list(self.__class__.__dict__.keys()):
+            if name in self.__class__.__dict__:
                 continue
 
             # The object.
@@ -139,7 +141,7 @@ class Relax_data_store(dict):
                 continue
 
             # Skip overwritten methods.
-            if name in list(self.__class__.__dict__.keys()):
+            if name in self.__class__.__dict__:
                 continue
 
             # Skip dictionary methods.
@@ -164,7 +166,8 @@ class Relax_data_store(dict):
         """
 
         # Loop over the keys of self.__dict__ and delete the corresponding object.
-        for key in list(self.__dict__.keys()):
+        keys = list(self.__dict__.keys())
+        for key in keys:
             # Delete the object.
             del self.__dict__[key]
 
@@ -333,7 +336,7 @@ class Relax_data_store(dict):
 
                 # Build the new frequency list structure.
                 dp.spectrometer_frq_list = []
-                for frq in dp.spectrometer_frq.values():
+                for frq in list(dp.spectrometer_frq.values()):
                     if frq not in dp.spectrometer_frq_list:
                         dp.spectrometer_frq_list.append(frq)
 
@@ -358,7 +361,7 @@ class Relax_data_store(dict):
         """
 
         # Test if the pipe already exists.
-        if pipe_name in list(self.instance.keys()):
+        if pipe_name in self.instance:
             raise RelaxPipeError(pipe_name)
 
         # Create a new container.
@@ -370,7 +373,7 @@ class Relax_data_store(dict):
         # The pipe bundle.
         if bundle:
             # A new bundle.
-            if bundle not in list(self.pipe_bundles.keys()):
+            if bundle not in self.pipe_bundles:
                 self.pipe_bundles[bundle] = []
 
             # Add the pipe to the bundle.
@@ -396,25 +399,25 @@ class Relax_data_store(dict):
         """
 
         # No pipes should exist.
-        if not list(self.keys()) == []:
+        if len(self):
             if verbosity:
-                stderr.write("The relax data store contains the data pipes %s.\n" % list(self.keys()))
+                stderr.write("The relax data store contains the data pipes %s.\n" % sorted(self.keys()))
             return False
 
         # Objects which should be in here.
         blacklist = [
-                'pipe_bundles',
-                'relax_gui'
+            'pipe_bundles',
+            'relax_gui'
         ]
 
         # An object has been added to the data store.
         for name in dir(self):
             # Skip the data store methods.
-            if name in list(self.__class__.__dict__.keys()):
+            if name in self.__class__.__dict__:
                 continue
 
             # Skip the dict methods.
-            if name in list(dict.__dict__.keys()):
+            if name in dict.__dict__:
                 continue
 
             # Skip special objects.
@@ -477,8 +480,17 @@ class Relax_data_store(dict):
         if gui_nodes:
             self.relax_gui.from_xml(gui_nodes[0], file_version=file_version)
 
+        # Get the sequence alignment nodes.
+        seq_align_nodes = relax_node.getElementsByTagName('sequence_alignments')
+        if seq_align_nodes:
+            # Initialise the object.
+            self.sequence_alignments = Sequence_alignments()
+
+            # Populate it.
+            self.sequence_alignments.from_xml(seq_align_nodes[0], file_version=file_version)
+
         # Recreate all the data store data structures.
-        xml_to_object(relax_node, self, file_version=file_version, blacklist=['pipe', 'relax_gui'])
+        xml_to_object(relax_node, self, file_version=file_version, blacklist=['pipe', 'relax_gui', 'sequence_alignments'])
 
         # Get the pipe nodes.
         pipe_nodes = relax_node.getElementsByTagName('pipe')
@@ -548,7 +560,7 @@ class Relax_data_store(dict):
                 pipes.append(pipe_name)
 
             # Set the current pipe.
-            if self.current_pipe in list(self.keys()):
+            if self.current_pipe in self:
                 builtins.cdp = self[self.current_pipe]
 
         # Finally update the molecule, residue, and spin metadata for each data pipe.
@@ -604,7 +616,7 @@ class Relax_data_store(dict):
 
         # Add all objects in the data store base object to the XML element.
         if all:
-            blacklist = list(list(self.__class__.__dict__.keys()) + list(dict.__dict__.keys()))
+            blacklist = list(self.__class__.__dict__.keys()) + list(dict.__dict__.keys())
             for name in dir(self):
                 # Skip blacklisted objects.
                 if name in blacklist:
