@@ -1,7 +1,7 @@
 ###############################################################################
 #                                                                             #
 # Copyright (C) 2009-2011 Michael Bieri                                       #
-# Copyright (C) 2010-2013 Edward d'Auvergne                                   #
+# Copyright (C) 2010-2015 Edward d'Auvergne                                   #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
 #                                                                             #
@@ -41,6 +41,17 @@ from status import Status; status = Status()
 from user_functions.data import Uf_info; uf_info = Uf_info()
 
 
+# Some IDs for the menu entries.
+MENU_RELAX_DATA_DELETE = wx.NewId()
+MENU_RELAX_DATA_DISPLAY = wx.NewId()
+MENU_SPECTROMETER_FREQUENCY = wx.NewId()
+MENU_RELAX_DATA_PEAK_INTENSITY_TYPE = wx.NewId()
+MENU_RELAX_DATA_TEMP_CALIBRATION = wx.NewId()
+MENU_RELAX_DATA_TEMP_CONTROL = wx.NewId()
+MENU_RELAX_DATA_TYPE = wx.NewId()
+
+
+
 class Relax_data_list(Base_list):
     """The GUI element for listing loaded relaxation data."""
 
@@ -99,7 +110,7 @@ class Relax_data_list(Base_list):
 
         # The current type.
         type = None
-        if hasattr(cdp, 'exp_info') and hasattr(cdp.exp_info, 'peak_intensity_type') and id in cdp.exp_info.peak_intensity_type.keys():
+        if hasattr(cdp, 'exp_info') and hasattr(cdp.exp_info, 'peak_intensity_type') and id in cdp.exp_info.peak_intensity_type:
             type = cdp.exp_info.peak_intensity_type[id]
 
         # Launch the dialog.
@@ -124,7 +135,7 @@ class Relax_data_list(Base_list):
 
         # The current method.
         method = None
-        if hasattr(cdp, 'exp_info') and hasattr(cdp.exp_info, 'temp_calibration') and id in cdp.exp_info.temp_calibration.keys():
+        if hasattr(cdp, 'exp_info') and hasattr(cdp.exp_info, 'temp_calibration') and id in cdp.exp_info.temp_calibration:
             method = cdp.exp_info.temp_calibration[id]
 
         # Launch the dialog.
@@ -149,7 +160,7 @@ class Relax_data_list(Base_list):
 
         # The current method.
         method = None
-        if hasattr(cdp, 'exp_info') and hasattr(cdp.exp_info, 'temp_control') and id in cdp.exp_info.temp_control.keys():
+        if hasattr(cdp, 'exp_info') and hasattr(cdp.exp_info, 'temp_control') and id in cdp.exp_info.temp_control:
             method = cdp.exp_info.temp_control[id]
 
         # Launch the dialog.
@@ -174,7 +185,7 @@ class Relax_data_list(Base_list):
 
         # The current type.
         type = None
-        if hasattr(cdp, 'ri_type') and id in cdp.ri_type.keys():
+        if hasattr(cdp, 'ri_type') and id in cdp.ri_type:
             type = cdp.ri_type[id]
 
         # Launch the dialog.
@@ -199,7 +210,7 @@ class Relax_data_list(Base_list):
 
         # The current frequency.
         frq = None
-        if hasattr(cdp, 'spectrometer_frq') and id in cdp.spectrometer_frq.keys():
+        if hasattr(cdp, 'spectrometer_frq') and id in cdp.spectrometer_frq:
             frq = cdp.spectrometer_frq[id]
 
         # Launch the dialog.
@@ -257,37 +268,37 @@ class Relax_data_list(Base_list):
         # The right click popup menu.
         self.popup_menus = [
             {
-                'id': wx.NewId(),
+                'id': MENU_RELAX_DATA_DELETE,
                 'text': "&Delete the relaxation data",
                 'icon': fetch_icon(uf_info.get_uf('relax_data.delete').gui_icon),
                 'method': self.action_relax_data_delete
             }, {
-                'id': wx.NewId(),
+                'id': MENU_RELAX_DATA_DISPLAY,
                 'text': "Dis&play the relaxation data",
                 'icon': fetch_icon(uf_info.get_uf('relax_data.display').gui_icon),
                 'method': self.action_relax_data_display
             }, {
-                'id': wx.NewId(),
+                'id': MENU_SPECTROMETER_FREQUENCY,
                 'text': "Set the relaxation data &frequency",
                 'icon': fetch_icon(uf_info.get_uf('spectrometer.frequency').gui_icon),
                 'method': self.action_spectrometer_frequency
             }, {
-                'id': wx.NewId(),
+                'id': MENU_RELAX_DATA_PEAK_INTENSITY_TYPE,
                 'text': "Set the peak &intensity type",
                 'icon': fetch_icon(uf_info.get_uf('relax_data.peak_intensity_type').gui_icon),
                 'method': self.action_relax_data_peak_intensity_type
             }, {
-                'id': wx.NewId(),
+                'id': MENU_RELAX_DATA_TEMP_CALIBRATION,
                 'text': "Set the temperature &calibration",
                 'icon': fetch_icon(uf_info.get_uf('relax_data.temp_calibration').gui_icon),
                 'method': self.action_relax_data_temp_calibration
             }, {
-                'id': wx.NewId(),
+                'id': MENU_RELAX_DATA_TEMP_CONTROL,
                 'text': "Set the temperature c&ontrol",
                 'icon': fetch_icon(uf_info.get_uf('relax_data.temp_control').gui_icon),
                 'method': self.action_relax_data_temp_control
             }, {
-                'id': wx.NewId(),
+                'id': MENU_RELAX_DATA_TYPE,
                 'text': "Set the relaxation data &type",
                 'icon': fetch_icon(uf_info.get_uf('relax_data.type').gui_icon),
                 'method': self.action_relax_data_type
@@ -362,6 +373,10 @@ class Relax_data_list(Base_list):
         else:
             title = "The relaxation data reading wizard"
 
+        # Destroy any pre-existing wizards.
+        if hasattr(self, 'wizard'):
+            self.wizard.Destroy()
+
         # Initialise a wizard.
         self.wizard = Wiz_window(parent=self.gui, size_x=1000, size_y=800, title=title)
         self.page_indices = {}
