@@ -39,6 +39,20 @@ from specific_analyses.relax_disp.data import is_cpmg_exp_type, is_r1rho_exp_typ
 from user_functions.data import Uf_info; uf_info = Uf_info()
 
 
+# Some IDs for the menu entries.
+MENU_SPECTRUM_BASEPLANE_RMSD = wx.NewId()
+MENU_SPECTRUM_DELETE = wx.NewId()
+MENU_SPECTRUM_INTEGRATION_POINTS = wx.NewId()
+MENU_SPECTRUM_REPLICATED = wx.NewId()
+MENU_RELAX_DISP_EXP_TYPE = wx.NewId()
+MENU_RELAX_FIT_RELAX_TIME = wx.NewId()
+MENU_RELAX_DISP_RELAX_TIME = wx.NewId()
+MENU_SPECTROMETER_FRQ = wx.NewId()
+MENU_RELAX_DISP_SPIN_LOCK_FIELD = wx.NewId()
+MENU_RELAX_DISP_SPIN_LOCK_OFFSET = wx.NewId()
+MENU_RELAX_DISP_CPMG_SETUP = wx.NewId()
+
+
 class Spectra_list(Base_list):
     """The GUI element for listing loaded spectral data."""
 
@@ -98,14 +112,14 @@ class Spectra_list(Base_list):
         # The current frequency.
         frq = None
         frq_flag = False
-        if hasattr(cdp, 'cpmg_frqs') and id in cdp.cpmg_frqs.keys():
+        if hasattr(cdp, 'cpmg_frqs') and id in cdp.cpmg_frqs:
             frq = cdp.cpmg_frqs[id]
             frq_flag = True
 
         # The current ncyc_even flag.
         even = True
         even_flag = False
-        if hasattr(cdp, 'ncyc_even') and id in cdp.ncyc_even.keys():
+        if hasattr(cdp, 'ncyc_even') and id in cdp.ncyc_even:
             even = cdp.ncyc_even[id]
             even_flag = True
 
@@ -134,7 +148,7 @@ class Spectra_list(Base_list):
 
         # The current type.
         exp_type = None
-        if hasattr(cdp, 'exp_type') and id in cdp.exp_type.keys():
+        if hasattr(cdp, 'exp_type') and id in cdp.exp_type:
             exp_type = cdp.exp_type[id]
 
         # Launch the dialog.
@@ -162,7 +176,7 @@ class Spectra_list(Base_list):
 
         # The current time.
         time = None
-        if hasattr(cdp, 'relax_times') and id in cdp.relax_times.keys():
+        if hasattr(cdp, 'relax_times') and id in cdp.relax_times:
             time = cdp.relax_times[id]
 
         # Launch the dialog.
@@ -191,7 +205,7 @@ class Spectra_list(Base_list):
         # The spin-lock.
         nu1 = None
         nu1_flag = False
-        if hasattr(cdp, 'spin_lock_nu1') and id in cdp.spin_lock_nu1.keys():
+        if hasattr(cdp, 'spin_lock_nu1') and id in cdp.spin_lock_nu1:
             nu1 = cdp.spin_lock_nu1[id]
             nu1_flag = True
 
@@ -221,7 +235,7 @@ class Spectra_list(Base_list):
         # The offset.
         offset = None
         offset_flag = False
-        if hasattr(cdp, 'spin_lock_offset') and id in cdp.spin_lock_offset.keys():
+        if hasattr(cdp, 'spin_lock_offset') and id in cdp.spin_lock_offset:
             offset = cdp.spin_lock_offset[id]
             offset_flag = True
 
@@ -250,7 +264,7 @@ class Spectra_list(Base_list):
 
         # The current time.
         time = None
-        if hasattr(cdp, 'relax_times') and id in cdp.relax_times.keys():
+        if hasattr(cdp, 'relax_times') and id in cdp.relax_times:
             time = cdp.relax_times[id]
 
         # Launch the dialog.
@@ -424,11 +438,11 @@ class Spectra_list(Base_list):
         # Set the values.
         for i in range(len(cdp.spectrum_ids)):
             # Set the CPMG frequency.
-            if hasattr(cdp, 'cpmg_frqs') and cdp.spectrum_ids[i] in cdp.cpmg_frqs.keys():
+            if hasattr(cdp, 'cpmg_frqs') and cdp.spectrum_ids[i] in cdp.cpmg_frqs:
                 self.element.SetStringItem(i, index, float_to_gui(cdp.cpmg_frqs[cdp.spectrum_ids[i]]))
 
             # Set the spin-lock field strength.
-            if hasattr(cdp, 'spin_lock_nu1') and cdp.spectrum_ids[i] in cdp.spin_lock_nu1.keys():
+            if hasattr(cdp, 'spin_lock_nu1') and cdp.spectrum_ids[i] in cdp.spin_lock_nu1:
                 self.element.SetStringItem(i, index, float_to_gui(cdp.spin_lock_nu1[cdp.spectrum_ids[i]]))
 
         # Successful.
@@ -454,7 +468,7 @@ class Spectra_list(Base_list):
         # Set the values.
         for i in range(len(cdp.spectrum_ids)):
             # No value.
-            if cdp.spectrum_ids[i] not in cdp.exp_type.keys():
+            if cdp.spectrum_ids[i] not in cdp.exp_type:
                 continue
 
             # Set the value.
@@ -513,7 +527,7 @@ class Spectra_list(Base_list):
 
         # Set the values.
         for i in range(len(cdp.spectrum_ids)):
-            if hasattr(cdp, 'spin_lock_offset') and cdp.spectrum_ids[i] in cdp.spin_lock_offset.keys():
+            if hasattr(cdp, 'spin_lock_offset') and cdp.spectrum_ids[i] in cdp.spin_lock_offset:
                 self.element.SetStringItem(i, index, float_to_gui(cdp.spin_lock_offset[cdp.spectrum_ids[i]]))
 
         # Successful.
@@ -532,22 +546,22 @@ class Spectra_list(Base_list):
         # The right click popup menu.
         popup_menus = [
             {
-                'id': wx.NewId(),
+                'id': MENU_SPECTRUM_BASEPLANE_RMSD,
                 'text': "Set the &baseplane RMSD",
                 'icon': fetch_icon(uf_info.get_uf('spectrum.baseplane_rmsd').gui_icon),
                 'method': self.action_spectrum_baseplane_rmsd
             }, {
-                'id': wx.NewId(),
+                'id': MENU_SPECTRUM_DELETE,
                 'text': "&Delete the peak intensities",
                 'icon': fetch_icon(uf_info.get_uf('spectrum.delete').gui_icon),
                 'method': self.action_spectrum_delete
             }, {
-                'id': wx.NewId(),
+                'id': MENU_SPECTRUM_INTEGRATION_POINTS,
                 'text': "Set the number of integration &points",
                 'icon': fetch_icon(uf_info.get_uf('spectrum.integration_points').gui_icon),
                 'method': self.action_spectrum_integration_points
             }, {
-                'id': wx.NewId(),
+                'id': MENU_SPECTRUM_REPLICATED,
                 'text': "Specify which spectra are &replicated",
                 'icon': fetch_icon(uf_info.get_uf('spectrum.replicated').gui_icon),
                 'method': self.action_spectrum_replicated
@@ -555,47 +569,47 @@ class Spectra_list(Base_list):
         ]
         if self.relax_disp_flag:
             popup_menus.append({
-                'id': wx.NewId(),
+                'id': MENU_RELAX_DISP_EXP_TYPE,
                 'text': "Set the &experiment type",
                 'icon': None,
                 'method': self.action_relax_disp_exp_type
             })
         if self.relax_fit_flag:
             popup_menus.append({
-                'id': wx.NewId(),
+                'id': MENU_RELAX_FIT_RELAX_TIME,
                 'text': "Set the relaxation &time",
                 'icon': fetch_icon(uf_info.get_uf('relax_fit.relax_time').gui_icon),
                 'method': self.action_relax_fit_relax_time
             })
         if self.relax_disp_flag:
             popup_menus.append({
-                'id': wx.NewId(),
+                'id': MENU_RELAX_DISP_RELAX_TIME,
                 'text': "Set the relaxation &time",
                 'icon': fetch_icon(uf_info.get_uf('relax_disp.relax_time').gui_icon),
                 'method': self.action_relax_disp_relax_time
             })
             popup_menus.append({
-                'id': wx.NewId(),
+                'id': MENU_SPECTROMETER_FRQ,
                 'text': "Set the spectrometer &frequency",
                 'icon': fetch_icon("relax.spectrometer"),
                 'method': self.action_spectrometer_frq
             })
         if self.relax_disp_flag and is_r1rho_exp_type(id):
             popup_menus.append({
-                'id': wx.NewId(),
+                'id': MENU_RELAX_DISP_SPIN_LOCK_FIELD,
                 'text': u("Set the spin-&lock field strength \u03BD1"),
                 'icon': fetch_icon("relax.relax_disp"),
                 'method': self.action_relax_disp_spin_lock_field
             })
             popup_menus.append({
-                'id': wx.NewId(),
+                'id': MENU_RELAX_DISP_SPIN_LOCK_OFFSET,
                 'text': u("Set the spin-&lock offset \u03C9_rf"),
                 'icon': fetch_icon("relax.relax_disp"),
                 'method': self.action_relax_disp_spin_lock_offset
             })
         if self.relax_disp_flag and is_cpmg_exp_type(id):
             popup_menus.append({
-                'id': wx.NewId(),
+                'id': MENU_RELAX_DISP_CPMG_SETUP,
                 'text': u("Set the &CPMG pulse sequence information"),
                 'icon': fetch_icon("relax.relax_disp"),
                 'method': self.action_relax_disp_cpmg_setup
@@ -634,7 +648,7 @@ class Spectra_list(Base_list):
         # Set the values.
         for i in range(len(cdp.spectrum_ids)):
             # No value.
-            if cdp.spectrum_ids[i] not in cdp.spectrum_type.keys():
+            if cdp.spectrum_ids[i] not in cdp.spectrum_type:
                 continue
 
             # Set the value.
@@ -667,7 +681,7 @@ class Spectra_list(Base_list):
         # Set the values.
         for i in range(len(cdp.spectrum_ids)):
             # No value.
-            if cdp.spectrum_ids[i] not in cdp.relax_times.keys():
+            if cdp.spectrum_ids[i] not in cdp.relax_times:
                 continue
 
             # Set the value.
