@@ -1,6 +1,6 @@
 ###############################################################################
 #                                                                             #
-# Copyright (C) 2010-2013 Edward d'Auvergne                                   #
+# Copyright (C) 2010-2015 Edward d'Auvergne                                   #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
 #                                                                             #
@@ -38,35 +38,36 @@ from pipe_control.selection import is_mol_selected, is_res_selected, is_spin_sel
 from status import Status; status = Status()
 
 
+# Some IDs for the menu entries.
+MENU_MOLECULE_MOLECULE_COPY = wx.NewId()
+MENU_MOLECULE_MOLECULE_DELETE = wx.NewId()
+MENU_MOLECULE_MOLECULE_DESELECT = wx.NewId()
+MENU_MOLECULE_MOLECULE_NAME = wx.NewId()
+MENU_MOLECULE_MOLECULE_SELECT = wx.NewId()
+MENU_MOLECULE_MOLECULE_TYPE = wx.NewId()
+MENU_MOLECULE_RESIDUE_CREATE = wx.NewId()
+MENU_RESIDUE_RESIDUE_COPY = wx.NewId()
+MENU_RESIDUE_RESIDUE_DELETE = wx.NewId()
+MENU_RESIDUE_RESIDUE_DESELECT = wx.NewId()
+MENU_RESIDUE_RESIDUE_NAME = wx.NewId()
+MENU_RESIDUE_RESIDUE_NUMBER = wx.NewId()
+MENU_RESIDUE_RESIDUE_SELECT = wx.NewId()
+MENU_RESIDUE_SPIN_ADD = wx.NewId()
+MENU_RESIDUE_SPIN_CREATE_PSEUDO = wx.NewId()
+MENU_ROOT_MOLECULE_CREATE = wx.NewId()
+MENU_ROOT_LOAD_SPINS = wx.NewId()
+MENU_SPIN_SPIN_COPY = wx.NewId()
+MENU_SPIN_SPIN_DELETE = wx.NewId()
+MENU_SPIN_SPIN_DESELECT = wx.NewId()
+MENU_SPIN_SPIN_ELEMENT = wx.NewId()
+MENU_SPIN_SPIN_NAME = wx.NewId()
+MENU_SPIN_SPIN_NUMBER = wx.NewId()
+MENU_SPIN_SPIN_SELECT = wx.NewId()
+
+
 class Mol_res_spin_tree(wx.Window):
     """The tree view class."""
 
-    # Some IDs for the menu entries.
-    MENU_MOLECULE_MOLECULE_COPY = wx.NewId()
-    MENU_MOLECULE_MOLECULE_DELETE = wx.NewId()
-    MENU_MOLECULE_MOLECULE_DESELECT = wx.NewId()
-    MENU_MOLECULE_MOLECULE_NAME = wx.NewId()
-    MENU_MOLECULE_MOLECULE_SELECT = wx.NewId()
-    MENU_MOLECULE_MOLECULE_TYPE = wx.NewId()
-    MENU_MOLECULE_RESIDUE_CREATE = wx.NewId()
-    MENU_RESIDUE_RESIDUE_COPY = wx.NewId()
-    MENU_RESIDUE_RESIDUE_DELETE = wx.NewId()
-    MENU_RESIDUE_RESIDUE_DESELECT = wx.NewId()
-    MENU_RESIDUE_RESIDUE_NAME = wx.NewId()
-    MENU_RESIDUE_RESIDUE_NUMBER = wx.NewId()
-    MENU_RESIDUE_RESIDUE_SELECT = wx.NewId()
-    MENU_RESIDUE_SPIN_ADD = wx.NewId()
-    MENU_RESIDUE_SPIN_CREATE_PSEUDO = wx.NewId()
-    MENU_ROOT_MOLECULE_CREATE = wx.NewId()
-    MENU_ROOT_LOAD_SPINS = wx.NewId()
-    MENU_SPIN_SPIN_COPY = wx.NewId()
-    MENU_SPIN_SPIN_DELETE = wx.NewId()
-    MENU_SPIN_SPIN_DESELECT = wx.NewId()
-    MENU_SPIN_SPIN_ELEMENT = wx.NewId()
-    MENU_SPIN_SPIN_NAME = wx.NewId()
-    MENU_SPIN_SPIN_NUMBER = wx.NewId()
-    MENU_SPIN_SPIN_SELECT = wx.NewId()
-
     def __init__(self, gui, parent=None, id=None):
         """Set up the tree GUI element.
 
@@ -529,18 +530,20 @@ class Mol_res_spin_tree(wx.Window):
         menu = wx.Menu()
 
         # The load spins entry.
-        item = build_menu_item(menu, id=self.MENU_ROOT_LOAD_SPINS, text="Load spins", icon=fetch_icon("relax.spin", "16x16"))
+        item = build_menu_item(menu, id=MENU_ROOT_LOAD_SPINS, text="Load spins", icon=fetch_icon("relax.spin", "16x16"))
         menu.AppendItem(item)
         if status.exec_lock.locked():
             item.Enable(False)
 
         # The menu actions.
-        self.Bind(wx.EVT_MENU, self.gui.spin_viewer.load_spins_wizard, id=self.MENU_ROOT_LOAD_SPINS)
+        self.Bind(wx.EVT_MENU, self.gui.spin_viewer.load_spins_wizard, id=MENU_ROOT_LOAD_SPINS)
 
         # Show the menu.
         if status.show_gui:
             self.PopupMenu(menu)
-            menu.Destroy()
+
+        # Cleanup.
+        menu.Destroy()
 
 
     def menu_molecule(self):
@@ -553,11 +556,11 @@ class Mol_res_spin_tree(wx.Window):
         menu = wx.Menu()
 
         # Add some menu items for the spin user functions.
-        items.append(build_menu_item(menu, id=self.MENU_MOLECULE_MOLECULE_COPY, text="&Copy the molecule", icon=fetch_icon("oxygen.actions.list-add")))
-        items.append(build_menu_item(menu, id=self.MENU_MOLECULE_MOLECULE_DELETE, text="De&lete the molecule", icon=fetch_icon("oxygen.actions.list-remove")))
-        items.append(build_menu_item(menu, id=self.MENU_MOLECULE_MOLECULE_NAME, text="&Name the molecule", icon=fetch_icon("oxygen.actions.edit-rename")))
-        items.append(build_menu_item(menu, id=self.MENU_MOLECULE_MOLECULE_TYPE, text="Set the molecule &type", icon=fetch_icon("oxygen.actions.edit-rename")))
-        items.append(build_menu_item(menu, id=self.MENU_MOLECULE_RESIDUE_CREATE, text="Add a &residue", icon=fetch_icon("oxygen.actions.list-add-relax-blue")))
+        items.append(build_menu_item(menu, id=MENU_MOLECULE_MOLECULE_COPY, text="&Copy the molecule", icon=fetch_icon("oxygen.actions.list-add")))
+        items.append(build_menu_item(menu, id=MENU_MOLECULE_MOLECULE_DELETE, text="De&lete the molecule", icon=fetch_icon("oxygen.actions.list-remove")))
+        items.append(build_menu_item(menu, id=MENU_MOLECULE_MOLECULE_NAME, text="&Name the molecule", icon=fetch_icon("oxygen.actions.edit-rename")))
+        items.append(build_menu_item(menu, id=MENU_MOLECULE_MOLECULE_TYPE, text="Set the molecule &type", icon=fetch_icon("oxygen.actions.edit-rename")))
+        items.append(build_menu_item(menu, id=MENU_MOLECULE_RESIDUE_CREATE, text="Add a &residue", icon=fetch_icon("oxygen.actions.list-add-relax-blue")))
 
         # Add the items and activate them.
         for item in items:
@@ -570,28 +573,30 @@ class Mol_res_spin_tree(wx.Window):
 
         # Selection or deselection.
         if self.info['select']:
-            item = build_menu_item(menu, id=self.MENU_MOLECULE_MOLECULE_DESELECT, text="&Deselect", icon=fetch_icon("relax.molecule_grey"))
+            item = build_menu_item(menu, id=MENU_MOLECULE_MOLECULE_DESELECT, text="&Deselect", icon=fetch_icon("relax.molecule_grey"))
         else:
-            item = build_menu_item(menu, id=self.MENU_MOLECULE_MOLECULE_SELECT, text="&Select", icon=fetch_icon("relax.molecule"))
+            item = build_menu_item(menu, id=MENU_MOLECULE_MOLECULE_SELECT, text="&Select", icon=fetch_icon("relax.molecule"))
         menu.AppendItem(item)
         if status.exec_lock.locked():
             item.Enable(False)
 
         # The menu actions.
-        self.Bind(wx.EVT_MENU, self.action_molecule_molecule_copy, id=self.MENU_MOLECULE_MOLECULE_COPY)
-        self.Bind(wx.EVT_MENU, self.action_molecule_molecule_delete, id=self.MENU_MOLECULE_MOLECULE_DELETE)
-        self.Bind(wx.EVT_MENU, self.action_molecule_molecule_name, id=self.MENU_MOLECULE_MOLECULE_NAME)
-        self.Bind(wx.EVT_MENU, self.action_molecule_molecule_type, id=self.MENU_MOLECULE_MOLECULE_TYPE)
-        self.Bind(wx.EVT_MENU, self.action_molecule_residue_create, id=self.MENU_MOLECULE_RESIDUE_CREATE)
+        self.Bind(wx.EVT_MENU, self.action_molecule_molecule_copy, id=MENU_MOLECULE_MOLECULE_COPY)
+        self.Bind(wx.EVT_MENU, self.action_molecule_molecule_delete, id=MENU_MOLECULE_MOLECULE_DELETE)
+        self.Bind(wx.EVT_MENU, self.action_molecule_molecule_name, id=MENU_MOLECULE_MOLECULE_NAME)
+        self.Bind(wx.EVT_MENU, self.action_molecule_molecule_type, id=MENU_MOLECULE_MOLECULE_TYPE)
+        self.Bind(wx.EVT_MENU, self.action_molecule_residue_create, id=MENU_MOLECULE_RESIDUE_CREATE)
         if self.info['select']:
-            self.Bind(wx.EVT_MENU, self.action_molecule_molecule_deselect, id=self.MENU_MOLECULE_MOLECULE_DESELECT)
+            self.Bind(wx.EVT_MENU, self.action_molecule_molecule_deselect, id=MENU_MOLECULE_MOLECULE_DESELECT)
         else:
-            self.Bind(wx.EVT_MENU, self.action_molecule_molecule_select, id=self.MENU_MOLECULE_MOLECULE_SELECT)
+            self.Bind(wx.EVT_MENU, self.action_molecule_molecule_select, id=MENU_MOLECULE_MOLECULE_SELECT)
 
         # Show the menu.
         if status.show_gui:
             self.PopupMenu(menu)
-            menu.Destroy()
+
+        # Cleanup.
+        menu.Destroy()
 
 
     def menu_residue(self):
@@ -604,12 +609,12 @@ class Mol_res_spin_tree(wx.Window):
         menu = wx.Menu()
 
         # Add some menu items for the spin user functions.
-        items.append(build_menu_item(menu, id=self.MENU_RESIDUE_RESIDUE_COPY, text="&Copy the residue", icon=fetch_icon("oxygen.actions.list-add")))
-        items.append(build_menu_item(menu, id=self.MENU_RESIDUE_RESIDUE_DELETE, text="De&lete the residue", icon=fetch_icon("oxygen.actions.list-remove")))
-        items.append(build_menu_item(menu, id=self.MENU_RESIDUE_RESIDUE_NAME, text="&Name the residue", icon=fetch_icon("oxygen.actions.edit-rename")))
-        items.append(build_menu_item(menu, id=self.MENU_RESIDUE_RESIDUE_NUMBER, text="N&umber the residue", icon=fetch_icon("oxygen.actions.edit-rename")))
-        items.append(build_menu_item(menu, id=self.MENU_RESIDUE_SPIN_ADD, text="&Add a spin", icon=fetch_icon("oxygen.actions.list-add-relax-blue")))
-        items.append(build_menu_item(menu, id=self.MENU_RESIDUE_SPIN_CREATE_PSEUDO, text="Create a &pseudo-atom", icon=fetch_icon("oxygen.actions.list-add-relax-blue")))
+        items.append(build_menu_item(menu, id=MENU_RESIDUE_RESIDUE_COPY, text="&Copy the residue", icon=fetch_icon("oxygen.actions.list-add")))
+        items.append(build_menu_item(menu, id=MENU_RESIDUE_RESIDUE_DELETE, text="De&lete the residue", icon=fetch_icon("oxygen.actions.list-remove")))
+        items.append(build_menu_item(menu, id=MENU_RESIDUE_RESIDUE_NAME, text="&Name the residue", icon=fetch_icon("oxygen.actions.edit-rename")))
+        items.append(build_menu_item(menu, id=MENU_RESIDUE_RESIDUE_NUMBER, text="N&umber the residue", icon=fetch_icon("oxygen.actions.edit-rename")))
+        items.append(build_menu_item(menu, id=MENU_RESIDUE_SPIN_ADD, text="&Add a spin", icon=fetch_icon("oxygen.actions.list-add-relax-blue")))
+        items.append(build_menu_item(menu, id=MENU_RESIDUE_SPIN_CREATE_PSEUDO, text="Create a &pseudo-atom", icon=fetch_icon("oxygen.actions.list-add-relax-blue")))
 
         # Add the items and activate them.
         for item in items:
@@ -622,29 +627,31 @@ class Mol_res_spin_tree(wx.Window):
 
         # Selection or deselection.
         if self.info['select']:
-            item = build_menu_item(menu, id=self.MENU_RESIDUE_RESIDUE_DESELECT, text="&Deselect", icon=fetch_icon("relax.residue_grey"))
+            item = build_menu_item(menu, id=MENU_RESIDUE_RESIDUE_DESELECT, text="&Deselect", icon=fetch_icon("relax.residue_grey"))
         else:
-            item = build_menu_item(menu, id=self.MENU_RESIDUE_RESIDUE_SELECT, text="&Select", icon=fetch_icon("relax.residue"))
+            item = build_menu_item(menu, id=MENU_RESIDUE_RESIDUE_SELECT, text="&Select", icon=fetch_icon("relax.residue"))
         menu.AppendItem(item)
         if status.exec_lock.locked():
             item.Enable(False)
 
         # The menu actions.
-        self.Bind(wx.EVT_MENU, self.action_residue_residue_copy, id=self.MENU_RESIDUE_RESIDUE_COPY)
-        self.Bind(wx.EVT_MENU, self.action_residue_residue_delete, id=self.MENU_RESIDUE_RESIDUE_DELETE)
-        self.Bind(wx.EVT_MENU, self.action_residue_residue_name, id=self.MENU_RESIDUE_RESIDUE_NAME)
-        self.Bind(wx.EVT_MENU, self.action_residue_residue_number, id=self.MENU_RESIDUE_RESIDUE_NUMBER)
-        self.Bind(wx.EVT_MENU, self.action_residue_spin_add, id=self.MENU_RESIDUE_SPIN_ADD)
-        self.Bind(wx.EVT_MENU, self.action_residue_spin_create_pseudo, id=self.MENU_RESIDUE_SPIN_CREATE_PSEUDO)
+        self.Bind(wx.EVT_MENU, self.action_residue_residue_copy, id=MENU_RESIDUE_RESIDUE_COPY)
+        self.Bind(wx.EVT_MENU, self.action_residue_residue_delete, id=MENU_RESIDUE_RESIDUE_DELETE)
+        self.Bind(wx.EVT_MENU, self.action_residue_residue_name, id=MENU_RESIDUE_RESIDUE_NAME)
+        self.Bind(wx.EVT_MENU, self.action_residue_residue_number, id=MENU_RESIDUE_RESIDUE_NUMBER)
+        self.Bind(wx.EVT_MENU, self.action_residue_spin_add, id=MENU_RESIDUE_SPIN_ADD)
+        self.Bind(wx.EVT_MENU, self.action_residue_spin_create_pseudo, id=MENU_RESIDUE_SPIN_CREATE_PSEUDO)
         if self.info['select']:
-            self.Bind(wx.EVT_MENU, self.action_residue_residue_deselect, id=self.MENU_RESIDUE_RESIDUE_DESELECT)
+            self.Bind(wx.EVT_MENU, self.action_residue_residue_deselect, id=MENU_RESIDUE_RESIDUE_DESELECT)
         else:
-            self.Bind(wx.EVT_MENU, self.action_residue_residue_select, id=self.MENU_RESIDUE_RESIDUE_SELECT)
+            self.Bind(wx.EVT_MENU, self.action_residue_residue_select, id=MENU_RESIDUE_RESIDUE_SELECT)
 
         # Show the menu.
         if status.show_gui:
             self.PopupMenu(menu)
-            menu.Destroy()
+
+        # Cleanup.
+        menu.Destroy()
 
 
     def menu_root(self):
@@ -657,8 +664,8 @@ class Mol_res_spin_tree(wx.Window):
         menu = wx.Menu()
 
         # Add some menu items for the spin user functions.
-        items.append(build_menu_item(menu, id=self.MENU_ROOT_MOLECULE_CREATE, text="&Add a molecule", icon=fetch_icon("oxygen.actions.list-add-relax-blue")))
-        items.append(build_menu_item(menu, id=self.MENU_ROOT_LOAD_SPINS, text="&Load spins", icon=fetch_icon("relax.spin", "16x16")))
+        items.append(build_menu_item(menu, id=MENU_ROOT_MOLECULE_CREATE, text="&Add a molecule", icon=fetch_icon("oxygen.actions.list-add-relax-blue")))
+        items.append(build_menu_item(menu, id=MENU_ROOT_LOAD_SPINS, text="&Load spins", icon=fetch_icon("relax.spin", "16x16")))
 
         # Add the items and activate them.
         for item in items:
@@ -667,13 +674,15 @@ class Mol_res_spin_tree(wx.Window):
                 item.Enable(False)
 
         # The menu actions.
-        self.Bind(wx.EVT_MENU, self.action_root_molecule_create, id=self.MENU_ROOT_MOLECULE_CREATE)
-        self.Bind(wx.EVT_MENU, self.gui.spin_viewer.load_spins_wizard, id=self.MENU_ROOT_LOAD_SPINS)
+        self.Bind(wx.EVT_MENU, self.action_root_molecule_create, id=MENU_ROOT_MOLECULE_CREATE)
+        self.Bind(wx.EVT_MENU, self.gui.spin_viewer.load_spins_wizard, id=MENU_ROOT_LOAD_SPINS)
 
         # Show the menu.
         if status.show_gui:
             self.PopupMenu(menu)
-            menu.Destroy()
+
+        # Cleanup.
+        menu.Destroy()
 
 
     def menu_spin(self):
@@ -686,11 +695,11 @@ class Mol_res_spin_tree(wx.Window):
         menu = wx.Menu()
 
         # Add some menu items for the spin user functions.
-        items.append(build_menu_item(menu, id=self.MENU_SPIN_SPIN_COPY, text="&Copy the spin", icon=fetch_icon("oxygen.actions.list-add")))
-        items.append(build_menu_item(menu, id=self.MENU_SPIN_SPIN_DELETE, text="De&lete the spin", icon=fetch_icon("oxygen.actions.list-remove")))
-        items.append(build_menu_item(menu, id=self.MENU_SPIN_SPIN_ELEMENT, text="Set the element &type of the spin", icon=fetch_icon("oxygen.actions.edit-rename")))
-        items.append(build_menu_item(menu, id=self.MENU_SPIN_SPIN_NAME, text="&Name the spin", icon=fetch_icon("oxygen.actions.edit-rename")))
-        items.append(build_menu_item(menu, id=self.MENU_SPIN_SPIN_NUMBER, text="N&umber the spin", icon=fetch_icon("oxygen.actions.edit-rename")))
+        items.append(build_menu_item(menu, id=MENU_SPIN_SPIN_COPY, text="&Copy the spin", icon=fetch_icon("oxygen.actions.list-add")))
+        items.append(build_menu_item(menu, id=MENU_SPIN_SPIN_DELETE, text="De&lete the spin", icon=fetch_icon("oxygen.actions.list-remove")))
+        items.append(build_menu_item(menu, id=MENU_SPIN_SPIN_ELEMENT, text="Set the element &type of the spin", icon=fetch_icon("oxygen.actions.edit-rename")))
+        items.append(build_menu_item(menu, id=MENU_SPIN_SPIN_NAME, text="&Name the spin", icon=fetch_icon("oxygen.actions.edit-rename")))
+        items.append(build_menu_item(menu, id=MENU_SPIN_SPIN_NUMBER, text="N&umber the spin", icon=fetch_icon("oxygen.actions.edit-rename")))
 
         # Add the items and activate them.
         for item in items:
@@ -703,28 +712,30 @@ class Mol_res_spin_tree(wx.Window):
 
         # Selection or deselection.
         if self.info['select']:
-            item = build_menu_item(menu, id=self.MENU_SPIN_SPIN_DESELECT, text="&Deselect", icon=fetch_icon("relax.spin_grey"))
+            item = build_menu_item(menu, id=MENU_SPIN_SPIN_DESELECT, text="&Deselect", icon=fetch_icon("relax.spin_grey"))
         else:
-            item = build_menu_item(menu, id=self.MENU_SPIN_SPIN_SELECT, text="&Select", icon=fetch_icon("relax.spin"))
+            item = build_menu_item(menu, id=MENU_SPIN_SPIN_SELECT, text="&Select", icon=fetch_icon("relax.spin"))
         menu.AppendItem(item)
         if status.exec_lock.locked():
             item.Enable(False)
 
         # The menu actions.
-        self.Bind(wx.EVT_MENU, self.action_spin_spin_copy, id=self.MENU_SPIN_SPIN_COPY)
-        self.Bind(wx.EVT_MENU, self.action_spin_spin_delete, id=self.MENU_SPIN_SPIN_DELETE)
-        self.Bind(wx.EVT_MENU, self.action_spin_spin_element, id=self.MENU_SPIN_SPIN_ELEMENT)
-        self.Bind(wx.EVT_MENU, self.action_spin_spin_name, id=self.MENU_SPIN_SPIN_NAME)
-        self.Bind(wx.EVT_MENU, self.action_spin_spin_number, id=self.MENU_SPIN_SPIN_NUMBER)
+        self.Bind(wx.EVT_MENU, self.action_spin_spin_copy, id=MENU_SPIN_SPIN_COPY)
+        self.Bind(wx.EVT_MENU, self.action_spin_spin_delete, id=MENU_SPIN_SPIN_DELETE)
+        self.Bind(wx.EVT_MENU, self.action_spin_spin_element, id=MENU_SPIN_SPIN_ELEMENT)
+        self.Bind(wx.EVT_MENU, self.action_spin_spin_name, id=MENU_SPIN_SPIN_NAME)
+        self.Bind(wx.EVT_MENU, self.action_spin_spin_number, id=MENU_SPIN_SPIN_NUMBER)
         if self.info['select']:
-            self.Bind(wx.EVT_MENU, self.action_spin_spin_deselect, id=self.MENU_SPIN_SPIN_DESELECT)
+            self.Bind(wx.EVT_MENU, self.action_spin_spin_deselect, id=MENU_SPIN_SPIN_DESELECT)
         else:
-            self.Bind(wx.EVT_MENU, self.action_spin_spin_select, id=self.MENU_SPIN_SPIN_SELECT)
+            self.Bind(wx.EVT_MENU, self.action_spin_spin_select, id=MENU_SPIN_SPIN_SELECT)
 
         # Show the menu.
         if status.show_gui:
             self.PopupMenu(menu)
-            menu.Destroy()
+
+        # Cleanup.
+        menu.Destroy()
 
 
     def prune_mol(self):
@@ -735,14 +746,22 @@ class Mol_res_spin_tree(wx.Window):
 
         # Find if the molecule has been removed.
         prune_list = []
-        for key in self.tree_ids.keys():
+        for key in self.tree_ids:
             # Get the python data.
             info = self.tree.GetItemPyData(key)
 
-            # Prune if it has been removed.
+            # No info.
+            if info == None or 'id' not in info:
+                continue
+
+            # Add to the prune list if it has been removed.
             if info['id'] not in mol_ids:
-                self.tree.Delete(key)
-                self.tree_ids.pop(key)
+                prune_list.append(key)
+
+        # Delete the data.
+        for key in prune_list:
+            self.tree.Delete(key)
+            self.tree_ids.pop(key)
 
 
     def prune_res(self, mol_branch_id, mol_id):
@@ -756,17 +775,25 @@ class Mol_res_spin_tree(wx.Window):
 
         # Find if the molecule has been removed.
         prune_list = []
-        for key in self.tree_ids[mol_branch_id].keys():
+        for key in self.tree_ids[mol_branch_id]:
             # Get the python data.
             info = self.tree.GetItemPyData(key)
 
+            # No info.
+            if info == None or 'id' not in info:
+                continue
+
             # Get the residue.
             res = return_residue(info['id'])
 
-            # Prune if it has been removed or renamed/renumbered.
+            # Add to the prune list if it has been removed or renamed/renumbered.
             if res == None or res.name != info['res_name'] or res.num != info['res_num']:
-                self.tree.Delete(key)
-                self.tree_ids[mol_branch_id].pop(key)
+                prune_list.append(key)
+
+        # Delete the data.
+        for key in prune_list:
+            self.tree.Delete(key)
+            self.tree_ids[mol_branch_id].pop(key)
 
 
     def prune_spin(self, mol_branch_id, res_branch_id, res_id):
@@ -782,17 +809,25 @@ class Mol_res_spin_tree(wx.Window):
 
         # Find if the molecule has been removed.
         prune_list = []
-        for key in self.tree_ids[mol_branch_id][res_branch_id].keys():
+        for key in self.tree_ids[mol_branch_id][res_branch_id]:
             # Get the python data.
             info = self.tree.GetItemPyData(key)
 
+            # No info.
+            if info == None or 'id' not in info:
+                continue
+
             # Get the spin.
             spin = return_spin(info['id'])
 
-            # Prune if it has been removed or renamed/renumbered.
+            # Add to the prune list if it has been removed or renamed/renumbered.
             if spin == None or spin.name != info['spin_name'] or spin.num != info['spin_num']:
-                self.tree.Delete(key)
-                self.tree_ids[mol_branch_id][res_branch_id].pop(key)
+                prune_list.append(key)
+
+        # Delete the data.
+        for key in prune_list:
+            self.tree.Delete(key)
+            self.tree_ids[mol_branch_id][res_branch_id].pop(key)
 
 
     def set_bitmap_mol(self, mol_branch_id, select=True):
@@ -903,10 +938,14 @@ class Mol_res_spin_tree(wx.Window):
 
         # Find the molecule, if it already exists.
         new_mol = True
-        for key in self.tree_ids.keys():
+        for key in self.tree_ids:
             # Get the python data.
             data = self.tree.GetItemPyData(key)
 
+            # No info.
+            if data == None or 'id' not in data:
+                continue
+
             # Check the mol_id for a match and, if so, terminate to speed things up.
             if mol_id == data['id']:
                 new_mol = False
@@ -976,10 +1015,14 @@ class Mol_res_spin_tree(wx.Window):
 
         # Find the residue, if it already exists.
         new_res = True
-        for key in self.tree_ids[mol_branch_id].keys():
+        for key in self.tree_ids[mol_branch_id]:
             # Get the python data.
             data = self.tree.GetItemPyData(key)
 
+            # No info.
+            if data == None or 'id' not in data:
+                continue
+
             # Check the res_id, res name, and res number for a match and, if so, terminate to speed things up.
             if res_id == data['id'] and res.name == data['res_name'] and res.num == data['res_num']:
                 new_res = False
@@ -1052,10 +1095,14 @@ class Mol_res_spin_tree(wx.Window):
 
         # Find the spin, if it already exists.
         new_spin = True
-        for key in self.tree_ids[mol_branch_id][res_branch_id].keys():
+        for key in self.tree_ids[mol_branch_id][res_branch_id]:
             # Get the python data.
             data = self.tree.GetItemPyData(key)
 
+            # No info.
+            if data == None or 'id' not in data:
+                continue
+
             # Check the spin_id, spin name and spin number for a match and, if so, terminate to speed things up.
             if spin_id == data['id'] and spin.name == data['spin_name'] and spin.num == data['spin_num']:
                 new_spin = False
