@@ -68,7 +68,7 @@ Links
 More information on the IT99 model can be found in the:
 
     - U{relax wiki<http://wiki.nmr-relax.com/IT99>},
-    - U{relax manual<http://www.nmr-relax.com/manual/IT99_2_site_CPMG_model.html>},
+    - U{relax manual<http://www.nmr-relax.com/manual/The_IT99_2_site_CPMG_model.html>},
     - U{relaxation dispersion page of the relax website<http://www.nmr-relax.com/analyses/relaxation_dispersion.html#IT99>}.
 
 """
