@@ -1,7 +1,7 @@
 from __future__ import absolute_import
 ###############################################################################
 #                                                                             #
-# Copyright (C) 2003-2014 Edward d'Auvergne                                   #
+# Copyright (C) 2003-2015 Edward d'Auvergne                                   #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
 #                                                                             #
@@ -35,6 +35,54 @@ from lib.selection import spin_id_to_data_list
 from lib.warnings import RelaxWarning, RelaxFileEmptyWarning
 
 
+# The 3 letter to 1 letter amino acid code table.
+AA_CODES = {
+    "ALA": "A",
+    "ARG": "R",
+    "ASN": "N",
+    "ASP": "D",
+    "CYS": "C",
+    "GLU": "E",
+    "GLN": "Q",
+    "GLY": "G",
+    "HIS": "H",
+    "ILE": "I",
+    "LEU": "L",
+    "LYS": "K",
+    "MET": "M",
+    "PHE": "F",
+    "PRO": "P",
+    "SER": "S",
+    "THR": "T",
+    "TRP": "W",
+    "TYR": "Y",
+    "VAL": "V",
+}
+
+
+def aa_codes_three_to_one(code):
+    """Convert the given three letter amino acid code to the corresponding one letter code.
+
+    Any non-standard residues will be converted to '*'.
+
+
+    @param code:    The three letter amino acid code to convert.
+    @type code:     str
+    @return:        The corresponding one letter amino acid code, or '*'.
+    @rtype:         str
+    """
+
+    # Convert to uppercase.
+    upper_code = code.upper()
+
+    # The code exists.
+    if upper_code in AA_CODES:
+        return AA_CODES[upper_code]
+
+    # No code.
+    return '*'
+
+
 def read_spin_data(file=None, dir=None, file_data=None, spin_id_col=None, mol_name_col=None, res_num_col=None, res_name_col=None, spin_num_col=None, spin_name_col=None, data_col=None, error_col=None, sep=None, spin_id=None):
     """Generator function for reading the spin specific data from file.
 
@@ -84,7 +132,7 @@ def read_spin_data(file=None, dir=None, file_data=None, spin_id_col=None, mol_na
         raise RelaxError("If the 'spin_id_col' argument has been supplied, then the mol_name_col, res_name_col, res_num_col, spin_name_col, and spin_num_col must all be set to None.")
 
     # Minimum number of columns.
-    min_col_num = max(filter(None, [spin_id_col, mol_name_col, res_num_col, res_name_col, spin_num_col, spin_name_col, data_col, error_col]))
+    min_col_num = max([_f for _f in [spin_id_col, mol_name_col, res_num_col, res_name_col, spin_num_col, spin_name_col, data_col, error_col] if _f])
 
     # Extract the data from the file.
     if not file_data:
