@@ -1,6 +1,6 @@
 ###############################################################################
 #                                                                             #
-# Copyright (C) 2008-2014 Edward d'Auvergne                                   #
+# Copyright (C) 2008-2015 Edward d'Auvergne                                   #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
 #                                                                             #
@@ -142,16 +142,13 @@ class MolContainer:
         }
 
         # Translate amino acids.
-        for key in list(table.keys()):
+        for key in table:
             if element in table[key]:
                 element = key
                 break
 
-        # Allowed element list.
-        elements = ['H', 'C', 'N', 'O', 'F', 'P', 'S']
-
-        # Return the element, if in the list.
-        if element in elements:
+        # Return the element if it is in the periodic table.
+        if periodic_table.has_element(symbol=element):
             return element
 
         # Else, throw a warning.
@@ -456,7 +453,6 @@ class MolContainer:
         """Check if the container is empty."""
 
         # Set attributes.
-        if hasattr(self, 'mol_name'): return False
         if hasattr(self, 'file_name'): return False
         if hasattr(self, 'file_path'): return False
         if hasattr(self, 'file_mol_num'): return False
@@ -495,6 +491,22 @@ class MolContainer:
         return self.res_num[-1]
 
 
+    def loop_residues(self):
+        """Generator method for looping over the individual residues of the molecule.
+
+        @return:    The residue name and number.
+        @rtype:     str, int
+        """
+
+        # Loop over the atoms.
+        last_res = None
+        for i in range(len(self.atom_num)):
+            # A new residue.
+            if self.res_num[i] != last_res:
+                last_res = self.res_num[i]
+                yield self.res_name[i], self.res_num[i]
+
+
     def merge(self, mol_cont=None):
         """Merge the contents of the given molecule container into here.
 
