@@ -1,6 +1,6 @@
 ###############################################################################
 #                                                                             #
-# Copyright (C) 2003-2014 Edward d'Auvergne                                   #
+# Copyright (C) 2003-2015 Edward d'Auvergne                                   #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
 #                                                                             #
@@ -24,7 +24,7 @@
 
 # Python module imports.
 from copy import deepcopy
-from math import pi, sqrt
+from math import ceil, floor, pi, sqrt
 from numpy import array, float64, int32, ones, std, zeros
 from numpy.linalg import norm
 from random import gauss
@@ -39,8 +39,9 @@ from lib.io import open_write_file
 from lib.periodic_table import periodic_table
 from lib.physical_constants import pcs_constant
 from lib.sequence import read_spin_data, write_spin_data
+from lib.software import grace
 from lib.warnings import RelaxWarning, RelaxNoSpinWarning
-from pipe_control import grace, pipes
+from pipe_control import pipes
 from pipe_control.align_tensor import get_tensor_index, get_tensor_object, opt_uses_align_data, opt_uses_tensor
 from pipe_control.mol_res_spin import exists_mol_res_spin_data, generate_spin_id_unique, is_pseudoatom, return_spin, spin_index_loop, spin_loop
 from pipe_control.pipes import check_pipe
@@ -342,11 +343,15 @@ def copy(pipe_from=None, pipe_to=None, align_id=None):
                 spin_to.pcs_err[align_id] = spin_from.pcs_err[align_id]
 
 
-def corr_plot(format=None, file=None, dir=None, force=False):
+def corr_plot(format=None, title=None, subtitle=None, file=None, dir=None, force=False):
     """Generate a correlation plot of the measured vs. back-calculated PCSs.
 
     @keyword format:    The format for the plot file.  The following values are accepted: 'grace', a Grace plot; None, a plain text file.
     @type format:       str or None
+    @keyword title:     The title for the plot, overriding the default.
+    @type title:        None or str
+    @keyword subtitle:  The subtitle for the plot, overriding the default.
+    @type subtitle:     None or str
     @keyword file:      The file name or object to write to.
     @type file:         str or file object
     @keyword dir:       The name of the directory to place the file into (defaults to the current directory).
@@ -368,6 +373,10 @@ def corr_plot(format=None, file=None, dir=None, force=False):
 
     # Init.
     data = []
+    orig_title = title
+    if orig_title == None:
+        title = "PCS correlation plot"
+    axis_labels = ["Back-calculated PCS (ppm)", "Measured PCS (ppm)"]
 
     # The diagonal.
     data.append([[-100, -100, 0], [100, 100, 0]])
@@ -379,6 +388,8 @@ def corr_plot(format=None, file=None, dir=None, force=False):
             types.append(spin.element)
 
     # Loop over the PCS data.
+    min_pcs = 1e100
+    max_pcs = -1e100
     for align_id in cdp.pcs_ids:
         # Loop over the spin types.
         for i in range(len(types)):
@@ -393,7 +404,7 @@ def corr_plot(format=None, file=None, dir=None, force=False):
                     continue
 
                 # Error present.
-                if hasattr(spin, 'pcs_err') and align_id in spin.pcs_err.keys():
+                if hasattr(spin, 'pcs_err') and align_id in spin.pcs_err:
                     err_flag = True
                     break
 
@@ -408,15 +419,29 @@ def corr_plot(format=None, file=None, dir=None, force=False):
                     continue
 
                 # Skip if data is missing.
-                if not hasattr(spin, 'pcs') or not hasattr(spin, 'pcs_bc') or not align_id in spin.pcs.keys() or not align_id in spin.pcs_bc.keys():
+                if not hasattr(spin, 'pcs') or not hasattr(spin, 'pcs_bc') or not align_id in spin.pcs or not align_id in spin.pcs_bc:
+                    continue
+                if spin.pcs[align_id] == None or spin.pcs_bc[align_id] == None:
                     continue
 
                 # Append the data.
                 data[-1].append([spin.pcs_bc[align_id], spin.pcs[align_id]])
 
+                # The minimum of all data sets.
+                if spin.pcs[align_id] < min_pcs:
+                    min_pcs = spin.pcs[align_id]
+                if spin.pcs_bc[align_id] < min_pcs:
+                    min_pcs = spin.pcs_bc[align_id]
+
+                # The maximum of all data sets.
+                if spin.pcs[align_id] > max_pcs:
+                    max_pcs = spin.pcs[align_id]
+                if spin.pcs_bc[align_id] > max_pcs:
+                    max_pcs = spin.pcs_bc[align_id]
+
                 # Errors.
                 if err_flag:
-                    if hasattr(spin, 'pcs_err') and align_id in spin.pcs_err.keys():
+                    if hasattr(spin, 'pcs_err') and align_id in spin.pcs_err:
                         data[-1][-1].append(spin.pcs_err[align_id])
                     else:
                         data[-1][-1].append(None)
@@ -427,6 +452,10 @@ def corr_plot(format=None, file=None, dir=None, force=False):
     # The data size.
     size = len(data)
 
+    # Round the data limits.
+    max_pcs = ceil(max_pcs)
+    min_pcs = floor(min_pcs)
+
     # Only one data set.
     data = [data]
 
@@ -445,10 +474,10 @@ def corr_plot(format=None, file=None, dir=None, force=False):
                 set_names.append("%s (%s)" % (cdp.pcs_ids[i], types[j]))
 
         # The header.
-        grace.write_xy_header(file=file, title="PCS correlation plot", data_type=['pcs_bc', 'pcs'], sets=[size], set_names=[set_names], linestyle=[[2]+[0]*size], legend_pos=[[1, 0.5]])
+        grace.write_xy_header(file=file, title=title, subtitle=subtitle, world=[[min_pcs, min_pcs, max_pcs, max_pcs]], sets=[size], set_names=[set_names], linestyle=[[2]+[0]*size], data_type=['pcs_bc', 'pcs'], axis_labels=[axis_labels], tick_major_spacing=[[1, 1]], tick_minor_count=[[9, 9]], legend_pos=[[1, 0.5]])
 
         # The main data.
-        grace.write_xy_data(data=data, file=file, graph_type=graph_type)
+        grace.write_xy_data(data=data, file=file, graph_type=graph_type, autoscale=False)
 
 
 def delete(align_id=None):
@@ -545,13 +574,19 @@ def opt_uses_pcs(align_id):
     return True
 
 
-def q_factors(spin_id=None):
+def q_factors(spin_id=None, verbosity=1):
     """Calculate the Q factors for the PCS data.
 
     @keyword spin_id:   The spin ID string used to restrict the Q factor calculation to a subset of all spins.
     @type spin_id:      None or str
+    @keyword verbosity: A flag specifying the amount of information to print.  The higher the value, the greater the verbosity.
+    @type verbosity:    int
     """
 
+    # Initial printout.
+    if verbosity:
+        print("\nPCS Q factors:")
+
     # Check the pipe setup.
     check_pipe_setup(sequence=True)
 
@@ -613,6 +648,10 @@ def q_factors(spin_id=None):
             warn(RelaxWarning("No back-calculated PCS data can be found for the alignment ID '%s', skipping the PCS Q factor calculation for this alignment." % align_id))
             continue
 
+        # ID and PCS Q factor printout.
+        if verbosity:
+            print("    Alignment ID '%s':  %.3f" % (align_id, cdp.q_factors_pcs[align_id]))
+
     # The total Q factor.
     cdp.q_pcs = 0.0
     for id in cdp.q_factors_pcs:
@@ -752,11 +791,13 @@ def read(align_id=None, file=None, dir=None, file_data=None, spin_id_col=None, m
         cdp.pcs_ids.append(align_id)
 
 
-def return_pcs_data(sim_index=None):
+def return_pcs_data(sim_index=None, verbosity=0):
     """Set up the data structures for optimisation using PCSs as base data sets.
 
     @keyword sim_index: The index of the simulation to optimise.  This should be None if normal optimisation is desired.
     @type sim_index:    None or int
+    @keyword verbosity: A flag specifying the amount of information to print.  The higher the value, the greater the verbosity.
+    @type verbosity:    int
     @return:            The assembled data structures for using PCSs as the base data for optimisation.  These include:
                             - the PCS values.
                             - the unit vectors connecting the paramagnetic centre (the electron spin) to the spin.
@@ -767,6 +808,10 @@ def return_pcs_data(sim_index=None):
     @rtype:             tuple of (numpy rank-2 float64 array, numpy rank-2 float64 array, numpy rank-2 float64 array, list of float, list of float, numpy rank-1 int32 array)
     """
 
+    # Initial printout.
+    if verbosity:
+        print("\nPCS data counts:")
+
     # Data setup tests.
     if not hasattr(cdp, 'paramagnetic_centre') and (hasattr(cdp, 'paramag_centre_fixed') and cdp.paramag_centre_fixed):
         raise RelaxError("The paramagnetic centre has not yet been specified.")
@@ -828,7 +873,7 @@ def return_pcs_data(sim_index=None):
                 continue
 
             # Append the PCSs to the list.
-            if align_id in spin.pcs.keys():
+            if align_id in spin.pcs:
                 if sim_index != None:
                     pcs[-1].append(spin.pcs_sim[align_id][sim_index])
                 else:
@@ -837,13 +882,13 @@ def return_pcs_data(sim_index=None):
                 pcs[-1].append(None)
 
             # Append the PCS errors.
-            if hasattr(spin, 'pcs_err') and align_id in spin.pcs_err.keys():
+            if hasattr(spin, 'pcs_err') and align_id in spin.pcs_err:
                 pcs_err[-1].append(spin.pcs_err[align_id])
             else:
                 pcs_err[-1].append(None)
 
             # Append the weight.
-            if hasattr(spin, 'pcs_weight') and align_id in spin.pcs_weight.keys():
+            if hasattr(spin, 'pcs_weight') and align_id in spin.pcs_weight:
                 pcs_weight[-1].append(spin.pcs_weight[align_id])
             else:
                 pcs_weight[-1].append(1.0)
@@ -851,6 +896,10 @@ def return_pcs_data(sim_index=None):
             # Spin index.
             j = j + 1
 
+        # ID and PCS count printout.
+        if verbosity:
+            print("    Alignment ID '%s':  %i" % (align_id, j))
+
     # Pseudo-atom.
     for spin in spin_loop():
         if is_pseudoatom(spin):
@@ -1144,9 +1193,9 @@ def write(align_id=None, file=None, dir=None, bc=False, force=False):
             continue
 
         # Skip spins with no PCSs.
-        if not bc and (not hasattr(spin, 'pcs') or not align_id in spin.pcs.keys()):
+        if not bc and (not hasattr(spin, 'pcs') or not align_id in spin.pcs):
             continue
-        elif bc and (not hasattr(spin, 'pcs_bc') or align_id not in spin.pcs_bc.keys()):
+        elif bc and (not hasattr(spin, 'pcs_bc') or align_id not in spin.pcs_bc):
             continue
 
         # Append the spin data.
@@ -1163,7 +1212,7 @@ def write(align_id=None, file=None, dir=None, bc=False, force=False):
             values.append(spin.pcs[align_id])
 
         # The error.
-        if hasattr(spin, 'pcs_err') and align_id in spin.pcs_err.keys():
+        if hasattr(spin, 'pcs_err') and align_id in spin.pcs_err:
             errors.append(spin.pcs_err[align_id])
         else:
             errors.append(None)
