@@ -153,7 +153,7 @@ def assemble_data_seq_series(spin_id=None, x_data_name=None, y_data_name=None, p
 
         # The keys.
         if series_type == dict:
-            keys = list(val.keys())
+            keys = sorted(val.keys())
 
         # Loop over the series data.
         for j in range(len(val)):
@@ -204,7 +204,7 @@ def assemble_data_seq_series(spin_id=None, x_data_name=None, y_data_name=None, p
 
             # The keys.
             if series_type == dict:
-                keys = list(series_val.keys())
+                keys = sorted(series_val.keys())
 
             # Loop over the series data.
             for j in range(len(series_val)):
@@ -363,22 +363,22 @@ def assemble_data_series_series(spin_id=None, x_data_name=None, y_data_name=None
                 continue
 
             # The keys.
-            x_keys = list(x_val.keys())
-            y_keys = list(y_val.keys())
+            x_keys = sorted(x_val.keys())
+            y_keys = sorted(y_val.keys())
 
             # The keys do not match.
             if x_keys[0] in y_keys:
                 continue
 
             # Are the X keys in the Y values?
-            if x_keys[0] in y_val.values():
+            if x_keys[0] in list(y_val.values()):
                 keys_for_values = 'x'
                 for key in x_keys:
                     if key not in base_values:
                         base_values.append(key)
 
             # Are the Y keys in the X values?
-            elif y_keys[0] in x_val.values():
+            elif y_keys[0] in list(x_val.values()):
                 keys_for_values = 'y'
                 for key in y_keys:
                     if key not in base_values:
@@ -423,7 +423,7 @@ def assemble_data_series_series(spin_id=None, x_data_name=None, y_data_name=None
 
             # The keys.
             if x_type == dict:
-                keys = list(x_val.keys())
+                keys = sorted(x_val.keys())
 
             # Loop over the list data.
             for j in range(len(base_values)):
@@ -575,7 +575,7 @@ def fetch_1D_data(plot_data=None, data_name=None, spin=None, res_num=None, sim_n
                 if err != None:
                     err[i] = err[i] / return_conversion_factor(data_name)
         elif isinstance(val, dict):
-            for key in val.keys():
+            for key in val:
                 val[key] = val[key] / return_conversion_factor(data_name)
                 if err != None:
                     err[key] = err[key] / return_conversion_factor(data_name)
