@@ -1,6 +1,6 @@
 ###############################################################################
 #                                                                             #
-# Copyright (C) 2003-2014 Edward d'Auvergne                                   #
+# Copyright (C) 2003-2015 Edward d'Auvergne                                   #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
 #                                                                             #
@@ -24,7 +24,7 @@
 
 # Python module imports.
 from copy import deepcopy
-from math import pi, sqrt
+from math import ceil, floor, pi, sqrt
 from numpy import array, int32, float64, ones, transpose, zeros
 from numpy.linalg import norm
 import sys
@@ -129,7 +129,7 @@ def back_calc(align_id=None):
                 interatom.rdc_bc[id] += interatom.j_coupling
 
             # The absolute value.
-            if hasattr(interatom, 'absolute_rdc') and id in interatom.absolute_rdc.keys() and interatom.absolute_rdc[id]:
+            if hasattr(interatom, 'absolute_rdc') and id in interatom.absolute_rdc and interatom.absolute_rdc[id]:
                 interatom.rdc_bc[id] = abs(interatom.rdc_bc[id])
 
         # Increment the counter.
@@ -410,12 +410,14 @@ def corr_plot(format=None, title=None, subtitle=None, file=None, dir=None, force
     orig_title = title
     if orig_title == None:
         title = "RDC correlation plot"
-    axis_labels = ["Measured RDC (Hz)", "Back-calculated RDC (Hz)"]
+    axis_labels = ["Back-calculated RDC (Hz)", "Measured RDC (Hz)"]
 
     # The diagonal.
     data.append([[-100, -100, 0], [100, 100, 0]])
 
     # Loop over the RDC data.
+    min_rdc = 1e100
+    max_rdc = -1e100
     for align_id in cdp.rdc_ids:
         # Append a new list for this alignment.
         data.append([])
@@ -424,14 +426,16 @@ def corr_plot(format=None, title=None, subtitle=None, file=None, dir=None, force
         err_flag = False
         for interatom in interatomic_loop():
             # Error present.
-            if hasattr(interatom, 'rdc_err') and align_id in interatom.rdc_err.keys():
+            if hasattr(interatom, 'rdc_err') and align_id in interatom.rdc_err:
                 err_flag = True
                 break
 
         # Loop over the interatomic data.
         for interatom in interatomic_loop():
             # Skip if data is missing.
-            if not hasattr(interatom, 'rdc') or not hasattr(interatom, 'rdc_bc') or not align_id in interatom.rdc.keys() or not align_id in interatom.rdc_bc.keys():
+            if not hasattr(interatom, 'rdc') or not hasattr(interatom, 'rdc_bc') or not align_id in interatom.rdc or not align_id in interatom.rdc_bc:
+                continue
+            if interatom.rdc[align_id] == None or interatom.rdc_bc[align_id] == None:
                 continue
 
             # Convert between the 2D and D notation.
@@ -452,11 +456,23 @@ def corr_plot(format=None, title=None, subtitle=None, file=None, dir=None, force
                     axis_labels = ["Measured T = J+D (Hz)", "Back-calculated T = J+D (Hz)"]
 
             # Append the data.
-            data[-1].append([rdc, rdc_bc])
+            data[-1].append([rdc_bc, rdc])
+
+            # The minimum of all data sets.
+            if rdc < min_rdc:
+                min_rdc = rdc
+            if rdc_bc < min_rdc:
+                min_rdc = rdc_bc
+
+            # The maximum of all data sets.
+            if rdc > max_rdc:
+                max_rdc = rdc
+            if rdc_bc > max_rdc:
+                max_rdc = rdc_bc
 
             # Errors.
             if err_flag:
-                if hasattr(interatom, 'rdc_err') and align_id in interatom.rdc_err.keys():
+                if hasattr(interatom, 'rdc_err') and align_id in interatom.rdc_err:
                     data[-1][-1].append(convert(interatom.rdc_err[align_id], interatom.rdc_data_types[align_id], align_id))
                 else:
                     data[-1][-1].append(None)
@@ -467,6 +483,10 @@ def corr_plot(format=None, title=None, subtitle=None, file=None, dir=None, force
     # The data size.
     size = len(data)
 
+    # Round the data limits.
+    max_rdc = ceil(max_rdc)
+    min_rdc = floor(min_rdc)
+
     # Only one data set.
     data = [data]
 
@@ -479,7 +499,7 @@ def corr_plot(format=None, title=None, subtitle=None, file=None, dir=None, force
     # Grace file.
     if format == 'grace':
         # The header.
-        grace.write_xy_header(file=file, title=title, subtitle=subtitle, world=[[-50, -50, 50, 50]], sets=[size], set_names=[[None]+cdp.rdc_ids], linestyle=[[2]+[0]*size], data_type=['rdc', 'rdc_bc'], axis_labels=[axis_labels], tick_major_spacing=[[10, 10]], tick_minor_count=[[9, 9]], legend_pos=[[1, 0.5]])
+        grace.write_xy_header(file=file, title=title, subtitle=subtitle, world=[[min_rdc, min_rdc, max_rdc, max_rdc]], sets=[size], set_names=[[None]+cdp.rdc_ids], linestyle=[[2]+[0]*size], data_type=['rdc', 'rdc_bc'], axis_labels=[axis_labels], tick_major_spacing=[[10, 10]], tick_minor_count=[[9, 9]], legend_pos=[[1, 0.5]])
 
         # The main data.
         grace.write_xy_data(data=data, file=file, graph_type=graph_type, autoscale=False)
@@ -596,13 +616,19 @@ def opt_uses_rdc(align_id):
     return True
 
 
-def q_factors(spin_id=None):
+def q_factors(spin_id=None, verbosity=1):
     """Calculate the Q factors for the RDC data.
 
     @keyword spin_id:   The spin ID string used to restrict the Q factor calculation to a subset of all spins.
     @type spin_id:      None or str
+    @keyword verbosity: A flag specifying the amount of information to print.  The higher the value, the greater the verbosity.
+    @type verbosity:    int
     """
 
+    # Initial printout.
+    if verbosity:
+        print("\nRDC Q factors (norm1, norm2):")
+
     # Check the pipe setup.
     check_pipe_setup(sequence=True)
 
@@ -714,6 +740,10 @@ def q_factors(spin_id=None):
         # The second Q factor definition.
         cdp.q_factors_rdc_norm2[align_id] = sqrt(sse / D2_sum)
 
+        # ID and RDC Q factor printout.
+        if verbosity:
+            print("    Alignment ID '%s':  %.3f, %.3f" % (align_id, cdp.q_factors_rdc[align_id], cdp.q_factors_rdc_norm2[align_id]))
+
     # The total Q factor.
     cdp.q_rdc = 0.0
     cdp.q_rdc_norm2 = 0.0
@@ -926,11 +956,13 @@ def read(align_id=None, file=None, dir=None, file_data=None, data_type='D', spin
         cdp.rdc_ids.append(align_id)
 
 
-def return_rdc_data(sim_index=None):
+def return_rdc_data(sim_index=None, verbosity=0):
     """Set up the data structures for optimisation using RDCs as base data sets.
 
     @keyword sim_index: The index of the simulation to optimise.  This should be None if normal optimisation is desired.
     @type sim_index:    None or int
+    @keyword verbosity: A flag specifying the amount of information to print.  The higher the value, the greater the verbosity.
+    @type verbosity:    int
     @return:            The assembled data structures for using RDCs as the base data for optimisation.  These include:
                             - rdc, the RDC values.
                             - rdc_err, the RDC errors.
@@ -944,6 +976,10 @@ def return_rdc_data(sim_index=None):
     @rtype:             tuple of (numpy rank-2 float64 array, numpy rank-2 float64 array, numpy rank-2 float64 array, list of numpy rank-3 float64 arrays, list of lists of floats, numpy rank-2 int32 array, numpy rank-2 int32 array, numpy rank-2 float64 array, numpy rank-1 int32 array)
     """
 
+    # Initial printout.
+    if verbosity:
+        print("\nRDC data counts:")
+
     # Sort out pseudo-atoms first.  This only needs to be called once.
     setup_pseudoatom_rdc()
 
@@ -1078,6 +1114,7 @@ def return_rdc_data(sim_index=None):
         T_flags.append([])
 
         # Interatom loop.
+        j = 0
         for interatom in interatomic_loop():
             # Get the spins.
             spin1 = return_spin(interatom.spin_id1)
@@ -1102,7 +1139,7 @@ def return_rdc_data(sim_index=None):
             error = None
 
             # Normal set up.
-            if align_id in interatom.rdc.keys():
+            if align_id in interatom.rdc:
                 # The RDC.
                 if sim_index != None:
                     value = interatom.rdc_sim[align_id][sim_index]
@@ -1110,7 +1147,7 @@ def return_rdc_data(sim_index=None):
                     value = interatom.rdc[align_id]
 
                 # The error.
-                if hasattr(interatom, 'rdc_err') and align_id in interatom.rdc_err.keys():
+                if hasattr(interatom, 'rdc_err') and align_id in interatom.rdc_err:
                     # T values.
                     if T_flags[-1][-1]:
                         error = sqrt(interatom.rdc_err[align_id]**2 + interatom.j_coupling_err**2)
@@ -1126,17 +1163,24 @@ def return_rdc_data(sim_index=None):
             rdc_err[-1].append(error)
 
             # Append the weight.
-            if hasattr(interatom, 'rdc_weight') and align_id in interatom.rdc_weight.keys():
+            if hasattr(interatom, 'rdc_weight') and align_id in interatom.rdc_weight:
                 rdc_weight[-1].append(interatom.rdc_weight[align_id])
             else:
                 rdc_weight[-1].append(1.0)
 
             # Append the absolute value flag.
-            if hasattr(interatom, 'absolute_rdc') and align_id in interatom.absolute_rdc.keys():
+            if hasattr(interatom, 'absolute_rdc') and align_id in interatom.absolute_rdc:
                 absolute[-1].append(interatom.absolute_rdc[align_id])
             else:
                 absolute[-1].append(False)
 
+            # Interatom index.
+            j = j + 1
+
+        # ID and RDC count printout.
+        if verbosity:
+            print("    Alignment ID '%s':  %i" % (align_id, j))
+
     # Convert to numpy objects.
     rdc = array(rdc, float64)
     rdc_err = array(rdc_err, float64)
@@ -1282,9 +1326,9 @@ def write(align_id=None, file=None, dir=None, bc=False, force=False):
             continue
 
         # Skip containers with no RDCs.
-        if not bc and (not hasattr(interatom, 'rdc') or align_id not in interatom.rdc.keys()):
+        if not bc and (not hasattr(interatom, 'rdc') or align_id not in interatom.rdc):
             continue
-        elif bc and (not hasattr(interatom, 'rdc_bc') or align_id not in interatom.rdc_bc.keys()):
+        elif bc and (not hasattr(interatom, 'rdc_bc') or align_id not in interatom.rdc_bc):
             continue
 
         # Append the spin data.
@@ -1304,7 +1348,7 @@ def write(align_id=None, file=None, dir=None, bc=False, force=False):
             data[-1].append(repr(convert(interatom.rdc[align_id], data_type, align_id)))
 
         # The error.
-        if hasattr(interatom, 'rdc_err') and align_id in interatom.rdc_err.keys():
+        if hasattr(interatom, 'rdc_err') and align_id in interatom.rdc_err:
             data[-1].append(repr(convert(interatom.rdc_err[align_id], data_type, align_id)))
         else:
             data[-1].append(repr(None))
