@@ -27,7 +27,7 @@
 # Python module imports.
 import bmrblib
 from copy import deepcopy
-from numpy import int32, zeros
+from numpy import int32, sqrt, zeros
 from re import match, search
 import string
 import sys
@@ -354,7 +354,7 @@ class Relax_disp(API_base, API_common):
                 param_key = return_param_key_from_data(exp_type=exp_type, frq=frq, offset=offset, point=point)
 
                 # Skip missing data.
-                if not hasattr(current_spin, 'r2eff') or param_key not in current_spin.r2eff.keys():
+                if not hasattr(current_spin, 'r2eff') or param_key not in current_spin.r2eff:
                     continue
 
                 # Store the result.
@@ -421,7 +421,7 @@ class Relax_disp(API_base, API_common):
                 continue
 
             # Skip special objects.
-            if search('^_', data_name) or data_name in list(dp_from.__class__.__dict__.keys()):
+            if search('^_', data_name) or data_name in dp_from.__class__.__dict__:
                 continue
 
             # Get the original object.
@@ -1037,6 +1037,48 @@ class Relax_disp(API_base, API_common):
         return errors
 
 
+    def return_error_red_chi2(self, data_id=None):
+        """Return the standard deviation data structure, where standard deviation is from the overall gauss distribution described by the STD_fit of the goodness of fit, where STD_fit = sqrt(chi2/(N-p))
+
+        @param data_id: The tuple of the spin container and the exponential curve identifying key, as yielded by the base_data_loop() generator method.
+        @type data_id:  SpinContainer instance and float
+        @return:        The standard deviation data structure.
+        @rtype:         list of float
+        """
+
+        # The R2eff model.
+        if cdp.model_type == MODEL_R2EFF:
+            raise RelaxError("Drawing errors from the gauss distribution described by the STD_fit of the goodness of fit, is not possible for the '%s' model."%MODEL_R2EFF)
+
+        # Get the errors structure as above.
+        errors = self.return_error(data_id=data_id)
+
+        # Unpack the data.
+        spin, spin_id = data_id
+
+        # Loop over the spin groupings for the model.
+        for spin_ids in self.model_loop():
+            # If the spin of interest is in the returned spin cluster.
+            if spin_id in spin_ids:
+                # Get the statistics
+                k, n, chi2 = self.model_statistics(model_info=spin_ids)
+
+                # Calculate degrees of freedom.
+                dof = n - k
+
+                # Calculate reduced chi2, or named as the variance of the squared residuals.
+                red_chi2 = chi2 / float(dof)
+
+                # Calculated the standard deviation.
+                std_red_chi2 = sqrt(red_chi2)
+
+                # Replace values with the stored value.
+                for id in errors:
+                    errors[id] = std_red_chi2
+
+                return errors
+
+
     def return_value(self, spin, param, sim=None, bc=False):
         """Return the value and error corresponding to the parameter.
 
@@ -1123,8 +1165,8 @@ class Relax_disp(API_base, API_common):
             param_name, si, mi = param_index_to_param_info(index=index, spins=spins)
         else:
             param_name = aux_params[index - total_param_num]
-            si = 0
-            mi = 0
+            si = None
+            mi = None
 
         # The parameter error name.
         err_name = param_name + "_err"
@@ -1140,8 +1182,15 @@ class Relax_disp(API_base, API_common):
 
         # Model and auxiliary parameters.
         else:
-            for spin in spins:
-                setattr(spin, err_name, error)
+            # If clustered paramater:
+            if si == None:
+                for spin in spins:
+                    setattr(spin, err_name, error)
+
+            # If independent value.
+            else:
+                # Set the value.
+                setattr(spins[si], err_name, error)
 
 
     def set_param_values(self, param=None, value=None, index=None, spin_id=None, error=False, force=True):
@@ -1486,7 +1535,9 @@ class Relax_disp(API_base, API_common):
         if model_param:
             param_name, si, mi = param_index_to_param_info(index=index, spins=spins)
             if not param_name in ['r2eff', 'i0']:
-                si = 0
+                if si == None:
+                    si = 0
+
         else:
             param_name = aux_params[index - total_param_num]
             si = 0
