@@ -46,15 +46,7 @@ from specific_analyses.relax_disp.checks import check_disp_points, check_exp_typ
 from specific_analyses.relax_disp.data import average_intensity, count_spins, find_intensity_keys, has_exponential_exp_type, has_proton_mmq_cpmg, is_r1_optimised, loop_exp, loop_exp_frq_offset_point, loop_exp_frq_offset_point_time, loop_frq, loop_offset, loop_time, pack_back_calc_r2eff, return_cpmg_frqs, return_offset_data, return_param_key_from_data, return_r1_data, return_r2eff_arrays, return_spin_lock_nu1
 from specific_analyses.relax_disp.parameters import assemble_param_vector, disassemble_param_vector, linear_constraints, param_conversion, param_num, r1_setup
 from target_functions.relax_disp import Dispersion
-
-# C modules.
-if C_module_exp_fn:
-    from specific_analyses.relax_fit.optimisation import func_wrapper, dfunc_wrapper, d2func_wrapper
-    from target_functions.relax_fit import setup, back_calc_I
-    # Call the python wrapper function to help with list to numpy array conversion.
-    func = func_wrapper
-    dfunc = dfunc_wrapper
-    d2func = d2func_wrapper
+from target_functions.relax_fit_wrapper import Relax_fit_opt
 
 
 def back_calc_peak_intensities(spin=None, exp_type=None, frq=None, offset=None, point=None):
@@ -100,13 +92,13 @@ def back_calc_peak_intensities(spin=None, exp_type=None, frq=None, offset=None,
         scaling_list.append(1.0)
 
     # Initialise the relaxation fit functions.
-    setup(num_params=len(param_vector), num_times=len(times), values=values, sd=errors, relax_times=times, scaling_matrix=scaling_list)
+    model = Relax_fit_opt(model='exp', num_params=len(spin.params), values=values, errors=errors, relax_times=times, scaling_matrix=scaling_list)
 
     # Make a single function call.  This will cause back calculation and the data will be stored in the C module.
-    func(param_vector)
+    model.func(param_vector)
 
     # Get the data back.
-    results = back_calc_I()
+    results = model.back_calc_data()
 
     # Return the correct peak height.
     return results
@@ -411,11 +403,11 @@ def minimise_r2eff(spins=None, spin_ids=None, min_algor=None, min_options=None,
                     scaling_list.append(scaling_matrix[i, i])
 
             # Initialise the function to minimise.
-            setup(num_params=len(param_vector), num_times=len(times), values=values, sd=errors, relax_times=times, scaling_matrix=scaling_list)
+            model = Relax_fit_opt(model='exp', num_params=len(param_vector), values=values, errors=errors, relax_times=times, scaling_matrix=scaling_list)
 
             # Grid search.
             if search('^[Gg]rid', min_algor):
-                results = grid(func=func, args=(), num_incs=inc, lower=lower, upper=upper, A=A, b=b, verbosity=verbosity)
+                results = grid(func=model.func, args=(), num_incs=inc, lower=lower, upper=upper, A=A, b=b, verbosity=verbosity)
 
                 # Unpack the results.
                 param_vector, chi2, iter_count, warning = results
@@ -425,7 +417,7 @@ def minimise_r2eff(spins=None, spin_ids=None, min_algor=None, min_options=None,
 
             # Minimisation.
             else:
-                results = generic_minimise(func=func, dfunc=dfunc, d2func=d2func, args=(), x0=param_vector, min_algor=min_algor, min_options=min_options, func_tol=func_tol, grad_tol=grad_tol, maxiter=max_iterations, A=A, b=b, full_output=True, print_flag=verbosity)
+                results = generic_minimise(func=model.func, dfunc=model.dfunc, d2func=model.d2func, args=(), x0=param_vector, min_algor=min_algor, min_options=min_options, func_tol=func_tol, grad_tol=grad_tol, maxiter=max_iterations, A=A, b=b, full_output=True, print_flag=verbosity)
 
                 # Unpack the results.
                 if results == None:
