@@ -37,16 +37,14 @@ from dep_check import C_module_exp_fn
 from lib.errors import RelaxError, RelaxNoModelError, RelaxNoSequenceError
 from lib.text.sectioning import subsection
 from lib.warnings import RelaxDeselectWarning
-from pipe_control.mol_res_spin import exists_mol_res_spin_data, return_spin, spin_loop
+from pipe_control.mol_res_spin import check_mol_res_spin_data, return_spin, spin_loop
 from specific_analyses.api_base import API_base
 from specific_analyses.api_common import API_common
-from specific_analyses.relax_fit.optimisation import back_calc, d2func_wrapper, dfunc_wrapper, func_wrapper
+from specific_analyses.relax_fit.checks import check_model_setup
+from specific_analyses.relax_fit.optimisation import back_calc
 from specific_analyses.relax_fit.parameter_object import Relax_fit_params
 from specific_analyses.relax_fit.parameters import assemble_param_vector, disassemble_param_vector, linear_constraints
-
-# C modules.
-if C_module_exp_fn:
-    from target_functions.relax_fit import jacobian, setup
+from target_functions.relax_fit_wrapper import Relax_fit_opt
 
 
 class Relax_fit(API_base, API_common):
@@ -93,10 +91,6 @@ class Relax_fit(API_base, API_common):
         if not C_module_exp_fn:
             raise RelaxError("Relaxation curve fitting is not available.  Try compiling the C modules on your platform.")
 
-        # Perform checks.
-        if not cdp.curve_type == 'exp':
-            raise RelaxError("Only curve type of 'exp' is allowed for error estimation.  Set by: relax_fit.select_model('exp').")
-
         # Raise Error, if not optimised.
         if not (hasattr(spin, 'rx') and hasattr(spin, 'i0')):
             raise RelaxError("Spin '%s' does not contain optimised 'rx' and 'i0' values.  Try execute: minimise.execute(min_algor='Newton', constraints=False)"%(spin_id))
@@ -115,14 +109,11 @@ class Relax_fit(API_base, API_common):
                 top += 2
             subsection(file=sys.stdout, text="Estimating rx error for spin: %s"%spin_id, prespace=top)
 
-        # The keys.
-        keys = list(spin.peak_intensity.keys())
-
         # The peak intensities and times.
         values = []
         errors = []
         times = []
-        for key in keys:
+        for key in spin.peak_intensity:
             values.append(spin.peak_intensity[key])
             errors.append(spin.peak_intensity_err[key])
             times.append(cdp.relax_times[key])
@@ -132,19 +123,17 @@ class Relax_fit(API_base, API_common):
         errors = asarray(errors)
         times = asarray(times)
 
-        # Extract values.
-        rx = getattr(spin, 'rx')
-        i0 = getattr(spin, 'i0')
-
-        # Pack data
-        param_vector = [rx, i0]
+        # Create the parameter vector and scaling matrix (as a diagonalised list).
+        param_vector = assemble_param_vector(spin=spin)
+        scaling_list = []
+        for i in range(len(spin.params)):
+            scaling_list.append(1.0)
 
         # Initialise data in C code.
-        scaling_list = [1.0, 1.0]
-        setup(num_params=len(param_vector), num_times=len(times), values=values, sd=errors, relax_times=times, scaling_matrix=scaling_list)
+        model = Relax_fit_opt(model=spin.model, num_params=len(param_vector), values=values, errors=errors, relax_times=times, scaling_matrix=scaling_list)
 
         # Use the direct Jacobian from function.
-        jacobian_matrix_exp = transpose(asarray( jacobian(param_vector) ) )
+        jacobian_matrix_exp = transpose(asarray( model.jacobian(param_vector) ) )
         weights = 1. / errors**2
 
         # Return the matrices.
@@ -179,7 +168,7 @@ class Relax_fit(API_base, API_common):
             raise RelaxNoModelError
 
         # Loop over the spectral time points.
-        for id in list(cdp.relax_times.keys()):
+        for id in cdp.relax_times:
             # Back calculate the value.
             value = back_calc(spin=spin, relax_time_id=id)
 
@@ -227,8 +216,14 @@ class Relax_fit(API_base, API_common):
         @rtype:                 list of str
         """
 
-        # Simply return the two parameter names.
-        return ['rx', 'i0']
+        # Check that the model is setup.
+        check_model_setup()
+
+        # Unpack the data.
+        spin, spin_id = model_info
+
+        # Return the parameter names.
+        return spin.params
 
 
     def get_param_values(self, model_info=None, sim_index=None):
@@ -301,9 +296,8 @@ class Relax_fit(API_base, API_common):
         @type inc:                  list of lists of int
         """
 
-        # Test if sequence data is loaded.
-        if not exists_mol_res_spin_data():
-            raise RelaxNoSequenceError
+        # Checks.
+        check_mol_res_spin_data()
 
         # Loop over the sequence.
         model_index = 0
@@ -343,14 +337,11 @@ class Relax_fit(API_base, API_common):
             # Initialise the function to minimise.
             ######################################
 
-            # The keys.
-            keys = list(spin.peak_intensity.keys())
-
             # The peak intensities and times.
             values = []
             errors = []
             times = []
-            for key in keys:
+            for key in spin.peak_intensity:
                 # The values.
                 if sim_index == None:
                     values.append(spin.peak_intensity[key])
@@ -372,7 +363,8 @@ class Relax_fit(API_base, API_common):
                 for i in range(len(scaling_matrix[model_index])):
                     scaling_list.append(scaling_matrix[model_index][i, i])
 
-            setup(num_params=len(spin.params), num_times=len(values), values=values, sd=errors, relax_times=times, scaling_matrix=scaling_list)
+            # Set up the target function.
+            model = Relax_fit_opt(model=spin.model, num_params=len(spin.params), values=values, errors=errors, relax_times=times, scaling_matrix=scaling_list)
 
 
             # Setup the minimisation algorithm when constraints are present.
@@ -403,7 +395,7 @@ class Relax_fit(API_base, API_common):
 
             # Grid search.
             if search('^[Gg]rid', min_algor):
-                results = grid(func=func_wrapper, args=(), num_incs=inc[model_index], lower=lower[model_index], upper=upper[model_index], A=A, b=b, verbosity=verbosity)
+                results = grid(func=model.func, args=(), num_incs=inc[model_index], lower=lower[model_index], upper=upper[model_index], A=A, b=b, verbosity=verbosity)
 
                 # Unpack the results.
                 param_vector, chi2, iter_count, warning = results
@@ -413,7 +405,7 @@ class Relax_fit(API_base, API_common):
 
             # Minimisation.
             else:
-                results = generic_minimise(func=func_wrapper, dfunc=dfunc_wrapper, d2func=d2func_wrapper, args=(), x0=param_vector, min_algor=min_algor, min_options=min_options, func_tol=func_tol, grad_tol=grad_tol, maxiter=max_iterations, A=A, b=b, full_output=True, print_flag=verbosity)
+                results = generic_minimise(func=model.func, dfunc=model.dfunc, d2func=model.d2func, args=(), x0=param_vector, min_algor=min_algor, min_options=min_options, func_tol=func_tol, grad_tol=grad_tol, maxiter=max_iterations, A=A, b=b, full_output=True, print_flag=verbosity)
 
                 # Unpack the results.
                 if results == None:
@@ -485,9 +477,9 @@ class Relax_fit(API_base, API_common):
         if verbose:
             print("\nOver-fit spin deselection:")
 
-        # Test the sequence data exists.
-        if not exists_mol_res_spin_data():
-            raise RelaxNoSequenceError
+        # Checks.
+        check_mol_res_spin_data()
+        check_model_setup()
 
         # Loop over spin data.
         deselect_flag = False
@@ -512,7 +504,7 @@ class Relax_fit(API_base, API_common):
 
             # Check that the number of relaxation times is complete.
             if len(spin.peak_intensity) != len(cdp.relax_times):
-                raise RelaxError("The %s peak intensity points of the spin '%s' does not match the expected number of %s (the IDs %s do not match %s)." % (len(spin.peak_intensity), spin_id, len(cdp.relax_times), list(spin.peak_intensity.keys()), list(cdp.relax_times.keys())))
+                raise RelaxError("The %s peak intensity points of the spin '%s' does not match the expected number of %s (the IDs %s do not match %s)." % (len(spin.peak_intensity), spin_id, len(cdp.relax_times), sorted(spin.peak_intensity.keys()), sorted(cdp.relax_times.keys())))
 
         # Final printout.
         if verbose and not deselect_flag:
