@@ -161,6 +161,42 @@ class N_state_model(SystemTestCase):
             self.assertAlmostEqual(cdp.chi[i, i] * 1e32, cdp.chi_ref[i] * 1e32, 2)
 
 
+    def test_CaM_IQ_tensor_fit(self):
+        """Test the fitting of 5 alignment tensors for the published CaM-IQ RDC and PCS data."""
+
+        # Execute the script.
+        self.script_exec(status.install_path + sep+'test_suite'+sep+'system_tests'+sep+'scripts'+sep+'n_state_model'+sep+'CaM_IQ_tensor_fit.py')
+
+        # Check the optimised alignment tensor.
+        ids = ['dy', 'tb', 'tm', 'er', 'yb', 'ho']
+        A = [
+            [      -5.961228899750e-04,        4.522953035367e-06,        6.168887153854e-04,        7.863257718395e-04,       -2.695142351742e-04],
+            [      -1.383036217378e-04,       -4.939409871651e-04,        4.130289107370e-04,        7.687580236309e-04,       -3.692016717764e-04],
+            [      -9.960927192978e-05,        4.477678617640e-04,       -4.062486453226e-04,       -4.332178003608e-04,        3.806525171855e-04],
+            [      -1.703610649220e-05,        2.102104571469e-04,       -2.836097445400e-04,       -2.989888174606e-04,        1.326155627753e-04],
+            [       6.087542827320e-05,        1.644473726436e-05,       -1.804561551839e-04,       -1.544765971220e-04,        1.354612889609e-04],
+            [      -1.902819219985e-04,       -1.267359074456e-04,        2.303672688393e-04,        3.019676781386e-04,       -2.255708108877e-04]
+        ]
+        for i in range(len(A)):
+            print("Checking tensor '%s'." % ids[i])
+            self.assertAlmostEqual(cdp.align_tensors[i].Axx * 1e4, A[i][0] * 1e4)
+            self.assertAlmostEqual(cdp.align_tensors[i].Ayy * 1e4, A[i][1] * 1e4)
+            self.assertAlmostEqual(cdp.align_tensors[i].Axy * 1e4, A[i][2] * 1e4)
+            self.assertAlmostEqual(cdp.align_tensors[i].Axz * 1e4, A[i][3] * 1e4)
+            self.assertAlmostEqual(cdp.align_tensors[i].Ayz * 1e4, A[i][4] * 1e4)
+
+        # Check the optimised paramagnetic position.
+        centre = [  6.328315298868965,   8.951353997015001,  12.311128147383837]
+        self.assertAlmostEqual(cdp.paramagnetic_centre[0], centre[0])
+        self.assertAlmostEqual(cdp.paramagnetic_centre[1], centre[1])
+        self.assertAlmostEqual(cdp.paramagnetic_centre[2], centre[2])
+
+        # Check the minimisation stats.
+        self.assertAlmostEqual(cdp.chi2, 496.36267335850528)
+        self.assertAlmostEqual(cdp.q_rdc, 0.142825408910208)
+        self.assertAlmostEqual(cdp.q_pcs, 0.07265356890310298)
+
+
     def test_absolute_rdc(self):
         """Test the fitting of signless RDCs."""
 
@@ -505,7 +541,7 @@ class N_state_model(SystemTestCase):
                 # RDC checks.
                 if hasattr(spin_orig, 'rdc'):
                     # Check the keys.
-                    self.assertEqual(spin_orig.rdc.keys(), spin_new.rdc.keys())
+                    self.assertEqual(sorted(spin_orig.rdc.keys()), sorted(spin_new.rdc.keys()))
 
                     # Check the values.
                     if id in spin_orig.rdc:
@@ -514,7 +550,7 @@ class N_state_model(SystemTestCase):
                 # PCS checks.
                 if hasattr(spin_orig, 'pcs'):
                     # Check the keys.
-                    self.assertEqual(spin_orig.pcs.keys(), spin_new.pcs.keys())
+                    self.assertEqual(sorted(spin_orig.pcs.keys()), sorted(spin_new.pcs.keys()))
 
                     # Check the values.
                     if id in spin_orig.pcs:
