@@ -1,6 +1,6 @@
 ###############################################################################
 #                                                                             #
-# Copyright (C) 2006-2014 Edward d'Auvergne                                   #
+# Copyright (C) 2006-2015 Edward d'Auvergne                                   #
 # Copyright (C) 2014 Troels E. Linnet                                         #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
@@ -21,7 +21,7 @@
 ###############################################################################
 
 # Python module imports.
-from os import sep
+from os import F_OK, access, sep
 from re import search
 from tempfile import mkdtemp
 
@@ -204,6 +204,23 @@ class Relax_fit(SystemTestCase):
             pass
 
 
+    def test_bug_23244_Iinf_graph(self):
+        """Test that the auto-analysis creates the Iinf grace graphs, replicating U{bug #23244<https://gna.org/bugs/?23244>}."""
+
+        # Execute the script.
+        self.script_exec(status.install_path + sep+'test_suite'+sep+'system_tests'+sep+'scripts'+sep+'curve_fitting'+sep+'relax_fit_inversion_recovery.py')
+
+        # Check that the Iinf parameter files have been created.
+        self.assert_(access(ds.tmpdir+sep+'i0.out', F_OK))
+        self.assert_(access(ds.tmpdir+sep+'iinf.out', F_OK))
+        self.assert_(access(ds.tmpdir+sep+'rx.out', F_OK))
+
+        # Check that the Iinf grace graphs have been created.
+        self.assert_(access(ds.tmpdir+sep+'grace'+sep+'i0.agr', F_OK))
+        self.assert_(access(ds.tmpdir+sep+'grace'+sep+'iinf.agr', F_OK))
+        self.assert_(access(ds.tmpdir+sep+'grace'+sep+'rx.agr', F_OK))
+
+
     def test_curve_fitting_height(self):
         """Test the relaxation curve fitting C modules."""
 
@@ -289,6 +306,9 @@ class Relax_fit(SystemTestCase):
         # De select one more.
         self.interpreter.deselect.spin(':512@ND2')
 
+        # Set the relaxation curve type.
+        self.interpreter.relax_fit.select_model('exp')
+
         # Do automatic
         if True:
             relax_fit.Relax_fit(pipe_name=pipe_name, pipe_bundle=pipe_bundle, file_root='R2', results_dir=results_dir, grid_inc=GRID_INC, mc_sim_num=MC_SIM, view_plots=False)
@@ -296,15 +316,15 @@ class Relax_fit(SystemTestCase):
         else:
             # Prepare for finding dublictes.
 
-            # Collect all times, and matching spectrum id.
+            # Collect all times, and matching spectrum ID.
             all_times = []
             all_id = []
-            for s_id, time in cdp.relax_times.iteritems():
-                all_times.append(time)
-                all_id.append(s_id)
+            for spectrum_id in cdp.relax_times:
+                all_times.append(cdp.relax_times[spectrum_id])
+                all_id.append(spectrum_id)
     
             # Get the dublicates.
-            dublicates = map(lambda val: (val, [i for i in xrange(len(all_times)) if all_times[i] == val]), all_times)
+            dublicates = [(val, [i for i in range(len(all_times)) if all_times[i] == val]) for val in all_times]
     
             # Loop over the list of the mapping of times and duplications.
             list_dub_mapping = []
@@ -336,9 +356,6 @@ class Relax_fit(SystemTestCase):
             # Peak intensity error analysis.
             self.interpreter.spectrum.error_analysis()
 
-            # Set the relaxation curve type.
-            self.interpreter.relax_fit.select_model('exp')
-
             # Grid search.
             self.interpreter.minimise.grid_search(inc=GRID_INC)
 
@@ -454,6 +471,19 @@ class Relax_fit(SystemTestCase):
         self.check_curve_fitting()
 
 
+    def test_inversion_recovery(self):
+        """Test the fitting for the inversion recovery R1 experiment."""
+
+        # Execute the script.
+        self.script_exec(status.install_path + sep+'test_suite'+sep+'system_tests'+sep+'scripts'+sep+'relax_fit_exp_3param_inv_neg.py')
+
+        # Check the curve-fitting results.
+        spin = return_spin(":4@N")
+        self.assertAlmostEqual(spin.rx, 1.2)
+        self.assertAlmostEqual(spin.i0, 30.0)
+        self.assertAlmostEqual(spin.iinf, 22.0)
+
+
     def test_read_sparky(self):
         """The Sparky peak height loading test."""
 
@@ -503,6 +533,19 @@ class Relax_fit(SystemTestCase):
                     self.assertEqual(orig_spin.peak_intensity[id], new_spin.peak_intensity[id])
 
 
+    def test_saturation_recovery(self):
+        """Test the fitting for the saturation recovery R1 experiment."""
+
+        # Execute the script.
+        self.script_exec(status.install_path + sep+'test_suite'+sep+'system_tests'+sep+'scripts'+sep+'relax_fit_saturation_recovery.py')
+
+        # Check the curve-fitting results.
+        spin = return_spin(":17@H")
+        self.assertAlmostEqual(spin.chi2, 0.0)
+        self.assertAlmostEqual(spin.rx, 0.5)
+        self.assertAlmostEqual(spin.iinf/1e15, 1.0)
+
+
     def test_zooming_grid_search(self):
         """Test the relaxation curve fitting C modules."""
 
