@@ -297,18 +297,18 @@ uf.wizard_image = WIZARD_IMAGE_PATH + 'align_tensor.png'
 
 # The align_tensor.matrix_angles user function.
 uf = uf_info.add_uf('align_tensor.matrix_angles')
-uf.title = "Calculate the 5D angles between all alignment tensors."
+uf.title = "Calculate the angles between all alignment tensors."
 uf.title_short = "Alignment tensor angle calculation."
 uf.display = True
 uf.add_keyarg(
     name = "basis_set",
-    default = 0,
-    py_type = "int",
+    default = "matrix",
+    py_type = "str",
     desc_short = "basis set",
     desc = "The basis set to operate with.",
     wiz_element_type = "combo",
-    wiz_combo_choices = ["{Sxx, Syy, Sxy, Sxz, Syz}", "{Szz, Sxxyy, Sxy, Sxz, Syz}"],
-    wiz_combo_data = [0, 1]
+    wiz_combo_choices = ["Standard inter-matrix angles", "Irreducible 5D {A-2, A-1, A0, A1, A2}", "Unitary 9D {Sxx, Sxy, Sxz, ..., Szz}", "Unitary 5D {Sxx, Syy, Sxy, Sxz, Syz}", "Geometric 5D {Szz, Sxxyy, Sxy, Sxz, Syz}"],
+    wiz_combo_data = ["matrix", "irreducible 5D", "unitary 9D", "unitary 5D", "geometric 5D"]
 )
 uf.add_keyarg(
     name = "tensors",
@@ -320,13 +320,79 @@ uf.add_keyarg(
     wiz_read_only = True,
     can_be_none = True
 )
+uf.add_keyarg(
+    name = "angle_units",
+    default = "deg",
+    py_type = "str",
+    desc_short = "angle units",
+    desc = "The units for the angle parameters, either 'deg' or 'rad'.",
+    wiz_element_type = "combo",
+    wiz_combo_choices = ["Degrees", "Radian"],
+    wiz_combo_data = ["deg", "rad"]
+)
+uf.add_keyarg(
+    name = "precision",
+    default = 1,
+    py_type = "int",
+    min = 1,
+    max = 100,
+    desc_short = "printout precision",
+    desc = "The precision of the printed out angles.  The number corresponds to the number of figures to print after the decimal point."
+)
 # Description.
 uf.desc.append(Desc_container())
-uf.desc[-1].add_paragraph("This will calculate the angles between all loaded alignment tensors for the current data pipe.  The matrices are first converted to a 5D vector form and then then angles are calculated.  The angles are dependent on the basis set.  If the basis set is set to the default of 0, the vectors {Sxx, Syy, Sxy, Sxz, Syz} are used.  If the basis set is set to 1, the vectors {Szz, Sxxyy, Sxy, Sxz, Syz} are used instead.")
+uf.desc[-1].add_paragraph("This will calculate the inter-matrix angles between all loaded alignment tensors for the current data pipe.  For the vector basis sets, the matrices are first mapped to vector form and then then the inter-vector angles rather than inter-matrix angles are calculated.  The angles are dependent upon the basis set - linear maps produce identical results whereas non-linear maps result in different angles.  The basis set can be one of:")
+uf.desc[-1].add_item_list_element("'matrix'", "The standard inter-matrix angles.  This default option is a linear map, hence angles are preserved.  The angle is calculated via the arccos of the Euclidean inner product of the alignment matrices in rank-2, 3D form divided by the Frobenius norm ||A||_F of the matrices.")
+uf.desc[-1].add_item_list_element("'irreducible 5D'", "The inter-tensor vector angles for the irreducible spherical tensor 5D basis set {A-2, A-1, A0, A1, A2}.  This is a linear map, hence angles are preserved.  These are the spherical harmonic decomposition coefficients.")
+uf.desc[-1].add_item_list_element("'unitary 9D'", "The inter-tensor vector angles for the unitary 9D basis set {Sxx, Sxy, Sxz, Syx, Syy, Syz, Szx, Szy, Szz}.  This is a linear map, hence angles are preserved.")
+uf.desc[-1].add_item_list_element("'unitary 5D'", "The inter-tensor vector angles for the unitary 5D basis set {Sxx, Syy, Sxy, Sxz, Syz}.  This is a non-linear map, hence angles are not preserved.")
+uf.desc[-1].add_item_list_element("'geometric 5D'", "The inter-tensor vector angles for the geometric 5D basis set {Szz, Sxxyy, Sxy, Sxz, Syz}.  This is a non-linear map, hence angles are not preserved.  This is also the Pales standard notation.")
+uf.desc[-1].add_paragraph("The full matrix angle via the Euclidean inner product is defined as")
+uf.desc[-1].add_verbatim("""\
+                   /   <A1 , A2>   \ 
+    theta = arccos | ------------- | ,
+                   \ ||A1||.||A2|| / \
+""")
+uf.desc[-1].add_paragraph("where <a,b> is the Euclidean inner product and ||a|| is the Frobenius norm of the matrix.  For the irreducible spherical tensor 5D basis set, the Am components are defined as")
+uf.desc[-1].add_verbatim("""\
+            / 4pi \ 1/2
+       A0 = | --- |     Szz ,
+            \  5  /
+
+                / 8pi \ 1/2
+    A+/-1 = +/- | --- |     (Sxz +/- iSyz) ,
+                \ 15  /
+
+            / 2pi \ 1/2
+    A+/-2 = | --- |     (Sxx - Syy +/- 2iSxy) ,
+            \ 15  / \
+""")
+uf.desc[-1].add_paragraph("and, for this complex notation, the angle is")
+uf.desc[-1].add_verbatim("""\
+                   / Re(<A1|A2>) \ 
+    theta = arccos | ----------- | ,
+                   \  |A1|.|A2|  / \
+""")
+uf.desc[-1].add_paragraph("where the inner product is defined as")
+uf.desc[-1].add_verbatim("""\
+               ___
+               \      1    2*
+    <A1|A2> =   >   Am . Am   ,
+               /__
+              m=-2,2 \
+""")
+uf.desc[-1].add_paragraph("and where Am* = (-1)^m A-m, and the norm is defined as |A1| = Re(sqrt(<A1|A1>)).  For all other basis sets whereby the map is real matrix -> real vector, the inter-tensor angle is defined as")
+uf.desc[-1].add_verbatim("""\
+                   /  <A1|A2>  \ 
+    theta = arccos | --------- | ,
+                   \ |A1|.|A2| / \
+""")
+uf.desc[-1].add_paragraph("where the inner product <A1|A2> is simply the vector dot product and |A1| is the vector length.")
 uf.backend = align_tensor.matrix_angles
 uf.menu_text = "&matrix_angles"
 uf.gui_icon = "oxygen.categories.applications-education"
-uf.wizard_size = (800, 600)
+uf.wizard_height_desc = 450
+uf.wizard_size = (1000, 750)
 uf.wizard_image = WIZARD_IMAGE_PATH + 'align_tensor.png'
 
 
@@ -403,13 +469,13 @@ uf.title_short = "Alignment tensor SVD calculation."
 uf.display = True
 uf.add_keyarg(
     name = "basis_set",
-    default = 0,
-    py_type = "int",
+    default = "irreducible 5D",
+    py_type = "str",
     desc_short = "basis set",
     desc = "The basis set to operate with.",
     wiz_element_type = "combo",
-    wiz_combo_choices = ["{Sxx, Syy, Sxy, Sxz, Syz}", "{Szz, Sxxyy, Sxy, Sxz, Syz}"],
-    wiz_combo_data = [0, 1]
+    wiz_combo_choices = ["Irreducible 5D {A-2, A-1, A0, A1, A2}", "Unitary 9D {Sxx, Sxy, Sxz, ..., Szz}", "Unitary 5D {Sxx, Syy, Sxy, Sxz, Syz}", "Geometric 5D {Szz, Sxxyy, Sxy, Sxz, Syz}"],
+    wiz_combo_data = ["irreducible 5D", "unitary 9D", "unitary 5D", "geometric 5D"]
 )
 uf.add_keyarg(
     name = "tensors",
@@ -421,34 +487,81 @@ uf.add_keyarg(
     wiz_read_only = True,
     can_be_none = True
 )
+uf.add_keyarg(
+    name = "precision",
+    default = 4,
+    py_type = "int",
+    min = 1,
+    max = 100,
+    desc_short = "printout precision",
+    desc = "The precision of the printed out singular values and condition numbers.  The number corresponds to the number of figures to print after the decimal point."
+)
 # Description.
 uf.desc.append(Desc_container())
-uf.desc[-1].add_paragraph("This will perform a singular value decomposition of all tensors loaded for the current data pipe.  If the basis set is set to the default of 0, the matrix on which SVD will be performed is composed of the unitary basis set {Sxx, Syy, Sxy, Sxz, Syz} layed out as:")
-uf.desc[-1].add_verbatim("""
+uf.desc[-1].add_paragraph("This will perform a singular value decomposition for all alignment tensors and calculate the condition number.  The singular values and condition number are dependent on the basis set - linear maps produce identical results whereas non-linear maps result in different values.  The basis set can be one of:")
+uf.desc[-1].add_item_list_element("'irreducible 5D'", "The irreducible spherical tensor 5D basis set {A-2, A-1, A0, A1, A2}.  This is a linear map, hence angles, singular values, and condition number are preserved.  These are the spherical harmonic decomposition coefficients.")
+uf.desc[-1].add_item_list_element("'unitary 9D'", "The unitary 9D basis set {Sxx, Sxy, Sxz, Syx, Syy, Syz, Szx, Szy, Szz}.  This is a linear map, hence angles, singular values, and condition number are preserved.")
+uf.desc[-1].add_item_list_element("'unitary 5D'", "The unitary 5D basis set {Sxx, Syy, Sxy, Sxz, Syz}.  This is a non-linear map, hence angles, singular values, and condition number are not preserved.")
+uf.desc[-1].add_item_list_element("'geometric 5D'", "The geometric 5D basis set {Szz, Sxxyy, Sxy, Sxz, Syz}.  This is a non-linear map, hence angles, singular values, and condition number are not preserved.  This is also the Pales standard notation.")
+uf.desc[-1].add_paragraph("If the selected basis set is the default of 'irreducible 5D', the matrix on which SVD will be performed will be:")
+uf.desc[-1].add_verbatim("""\
+    | A-2(1) A-1(1) A0(1)  A1(1)  A2(1) |
+    | A-2(2) A-1(2) A0(2)  A1(2)  A2(2) |
+    | A-2(3) A-1(3) A0(3)  A1(3)  A2(3) |
+    |   .      .     .      .      .    |
+    |   .      .     .      .      .    |
+    |   .      .     .      .      .    |
+    | A-2(N) A-1(N) A0(N)  A1(N)  A2(N) |\
+""")
+uf.desc[-1].add_paragraph("If the selected basis set is 'unitary 9D', the matrix on which SVD will be performed will be:")
+uf.desc[-1].add_verbatim("""\
+    | Sxx1 Sxy1 Sxz1 Syx1 Syy1 Syz1 Szx1 Szy1 Szz1 |
+    | Sxx2 Sxy2 Sxz2 Syx2 Syy2 Syz2 Szx2 Szy2 Szz2 |
+    | Sxx3 Sxy3 Sxz3 Syx3 Syy3 Syz3 Szx3 Szy3 Szz3 |
+    |  .    .    .    .    .    .    .    .    .   |
+    |  .    .    .    .    .    .    .    .    .   |
+    |  .    .    .    .    .    .    .    .    .   |
+    | SxxN SxyN SxzN SyxN SyyN SyzN SzxN SzyN SzzN |\
+""")
+uf.desc[-1].add_paragraph("Otherwise if the selected basis set is 'unitary 5D', the matrix for SVD is:")
+uf.desc[-1].add_verbatim("""\
     | Sxx1 Syy1 Sxy1 Sxz1 Syz1 |
     | Sxx2 Syy2 Sxy2 Sxz2 Syz2 |
     | Sxx3 Syy3 Sxy3 Sxz3 Syz3 |
     |  .    .    .    .    .   |
     |  .    .    .    .    .   |
     |  .    .    .    .    .   |
-    | SxxN SyyN SxyN SxzN SyzN |
+    | SxxN SyyN SxyN SxzN SyzN |\
 """)
-uf.desc[-1].add_paragraph("If basis_set is set to 1, the geometric basis set consisting of the stretching and skewing parameters Szz and Sxx-yy respectively {Szz, Sxxyy, Sxy, Sxz, Syz} will be used instead.  The matrix is:")
-uf.desc[-1].add_verbatim("""
+uf.desc[-1].add_paragraph("Or if the selected basis set is 'geometric 5D', the stretching and skewing parameters Szz and Sxx-yy will be used instead and the matrix is:")
+uf.desc[-1].add_verbatim("""\
     | Szz1 Sxxyy1 Sxy1 Sxz1 Syz1 |
     | Szz2 Sxxyy2 Sxy2 Sxz2 Syz2 |
     | Szz3 Sxxyy3 Sxy3 Sxz3 Syz3 |
     |  .     .     .    .    .   |
     |  .     .     .    .    .   |
     |  .     .     .    .    .   |
-    | SzzN SxxyyN SxyN SxzN SyzN |
+    | SzzN SxxyyN SxyN SxzN SyzN |\
 """)
-uf.desc[-1].add_paragraph("The relationships between the geometric and unitary basis sets are:")
-uf.desc[-1].add_verbatim("""
+uf.desc[-1].add_paragraph("For the irreducible spherical tensor basis set, the Am components are defined as")
+uf.desc[-1].add_verbatim("""\
+            / 4pi \ 1/2
+       A0 = | --- |     Szz ,
+            \  5  /
+
+                / 8pi \ 1/2
+    A+/-1 = +/- | --- |     (Sxz +/- iSyz) ,
+                \ 15  /
+
+            / 2pi \ 1/2
+    A+/-2 = | --- |     (Sxx - Syy +/- 2iSxy) .
+            \ 15  / \
+""")
+uf.desc[-1].add_paragraph("The relationships between the geometric and unitary basis sets are")
+uf.desc[-1].add_verbatim("""\
     Szz = - Sxx - Syy,
-    Sxxyy = Sxx - Syy,
+    Sxxyy = Sxx - Syy.\
 """)
-uf.desc[-1].add_paragraph("The SVD values and condition number are dependent upon the basis set chosen.")
 uf.backend = align_tensor.svd
 uf.menu_text = "s&vd"
 uf.gui_icon = "oxygen.categories.applications-education"
