@@ -83,6 +83,13 @@ uf.add_keyarg(
     desc = "The spin ID string for restricting to subset of all selected spins.",
     can_be_none = True
 )
+uf.add_keyarg(
+    name = "verbosity",
+    default = 1,
+    py_type = "int",
+    desc_short = "verbosity level",
+    desc = "The amount of information to print out.  Set to zero to silence the user function, or one to see all messages."
+)
 # Description.
 uf.desc.append(Desc_container())
 uf.desc[-1].add_paragraph("For this to work, the back-calculated PCS data must first be generated by the analysis specific code.  Otherwise a warning will be given.")
